QLabel#OverrideLabel {
    color: #000000;
    background-color: #ADB5BD;
    @if $isPortrait {
        font-size: 24px;
    }
    @else {
        font-size: 16px;
    }
}

QPushButton#OverrideButton {
    color: #FFFFFF;
    background-color: #345475;
    font-size: 26px;
    border-radius: 5px;
}

QLabel#OverrideReadout {
    color: #000000;
    background-color: #ADB5BD;
    @if $isPortrait {
        font-size: 24px;
    }
    @else {
        font-size: 16px;
    }
    border-radius: 5px;
}

QSlider::groove:horizontal#OverrideSlider {
    border: 1px solid;
    height: 40px;
    background: #3399ff;
    margin: 5px;
}

QSlider::handle:horizontal#OverrideSlider {
    width: 60px;
    border: 1px solid;
    border-radius: 5px;
    background: #888888;
    margin: -2px 0px;
}

QSlider::tick:horizontal#OverrideSlider {
    background: white;
    border: 1px solid white;
    width: 2px;
    margin-top: 5px;
    height: 15px;
    position: relative;
}

QSlider::add-page:horizontal#OverrideSlider {
    background: none;
}

QSlider::sub-page:horizontal#OverrideSlider {
    background: none;
}