

QSlider::groove::horizontal#ConfirmSliderRed {
    border: 1px solid;
    height: 40px;
    background: #FF0000;
    margin: 5px;
}

QSlider::groove::horizontal#ConfirmSliderGreen {
    border: 1px solid;
    height: 40px;
    background: #3dc200;
    margin: 5px;
}

QSlider::handle::horizontal#ConfirmSliderRed {
    width: 60px;
    border: 1px solid;
    border-radius: 5px;
    background: #888888;
    margin: -2px 0px;
}

QSlider::handle::horizontal#ConfirmSliderGreen {
    width: 60px;
    border: 1px solid;
    border-radius: 5px;
    background: #888888;
    margin: -2px 0px;
}