QMenuBar#MenuBar {
    background-color: #444444;
    spacing: 10px;
    border: 1px solid #222222;
    font-size: 16px;
    color: #ffffff;
}

QMenuBar::item#MenuBar {
    color: #ffffff;
    background-color: #444444;
    padding: 4px 10px;
}

QMenu#MenuBar {
    background-color: #222222;  /* Dark background */
    color: #ffffff;               /* White text color */
    font-size: 16px;              /* Font size */
    border: 1px solid #555555;
}

QMenu::item:selected {            /* Appearance when hovered */
    background-color: #666666;
    color: white;
}

QLabel#MenuBar {
    color: #ffffff;               /* White text color */
    @if $isPortrait {
        font-size: 26px;
    }
    @else {
        font-size: 16px;
    }
}



// QMenu::item#MenuBar {
//     padding: 5px 25px 5px 20px;
//     color: #ffffff;
//     background-color: transparent;
// }


