QLabel#KeyboardTitle {
    color: #FFFFFF;
    font-size: 22px;
}

QLineEdit#KeyboardLineEdit {
    color: #FFFFFF;
    background-color: #444444;
    border: 2px solid #888888;
    font-size: 30px;
    border-radius: 5px;
}

QTextEdit#KeyboardLineEdit {
    color: #FFFFFF;
    background-color: #444444;
    border: 2px solid #888888;
    font-size: 30px;
    border-radius: 5px;
}

QPushButton#KeyboardButton {
    color: #FFFFFF;
    background-color: #345475;
    border-radius: 5px;
    padding: 5px;
    font-size: 22px;
    min-height: 60px;
    max-height: 60px;
    min-width: 50px;
    max-width: 120px;
}

QPushButton#KeyboardSpaceButton {
    color: #FFFFFF;
    background-color: #345475;
    border-radius: 5px;
    padding: 5px;
    font-size: 22px;
    min-height: 60px;
    max-height: 60px;
}

QPushButton#KeyboardButtonGreen {
    color: #FFFFFF;
    background-color: #008966;
    border-radius: 5px;
    padding: 5px;
    font-size: 22px;
    min-height: 60px;
    min-width: 60px;
}

QPushButton#KeyboardButtonDisabled {
    color: #000000;
    background-color: #969696;
    border-radius: 5px;
    padding: 5px;
    font-size: 22px;
    min-height: 60px;
    min-width: 60px;
}

QPushButton#KeyboardButtonRed {
    color: #FFFFFF;
    background-color: #d34739;
    border-radius: 5px;
    padding: 5px;
    font-size: 22px;
    min-height: 60px;
    min-width: 60px;
}