
QLabel#HardwareText {
    color: #FFFFFF;
    @if $isPortrait {
        font-size: 50px;
    }
    @else {
        font-size: 28px;
    }
}

QLabel#HardwareWarning {
    color: #FFFFFF;
    background: $warning-color;
    @if $isPortrait {
        font-size: 50px;
    }
    @else {
        font-size: 28px;
    }
}

QLabel#HardwareOK {
    color: #FFFFFF;
    background: $ok-color;
    @if $isPortrait {
        font-size: 50px;
    }
    @else {
        font-size: 28px;
    }
}

QLabel#HardwareTimeZone {
    color: #FFFFFF;
    font-size: 28px;
}

QScrollArea#Diagnostics {
    color: #FFFFFF;
    background-color: #222222;
    font-size: 28px;
    border: 3px solid white;
    border-radius: 5px;
    padding: 20px 0px 0px 0px;
    margin-top: 20px;
}

QWidget #Diagnostics{
    background-color: #222222;
}