QWidget#Streaming {
    background-color: $main-background;
}

QLabel#StreamingLabel {
    color: #FFFFFF;
}

QPushButton#StreamingButton {
    color: #FFFFFF;
    background-color: #345475;
    border-radius: 5px;
}

QPushButton#StreamingButtonActive {
    color: #FFFFFF;
    background-color: #008966;
    border-radius: 5px;
}

QPushButton#StreamingButtonDisabled {
    color: #FFFFFF;
    background-color: #444444;
    border-radius: 5px;
}

QProgressBar#StreamingProgress {
    color: #FFFFFF;
    text-align: center;
    background-color: #444444;
    border: 2px solid white;
    border-radius: 5px;
    margin: 0.5px;
}

QProgressBar#StreamingProgress::chunk {
    background-color: green;
}

QToolButton#StreamingButton {
    color: #FFFFFF;
    background-color: #345475;
    border-radius: 5px;
}

QToolButton#StreamingButtonDisabled {
    color: #FFFFFF;
    background-color: #444444;
    border-radius: 5px;
}