QLabel#MessageTitle {
    color: #FFFFFF;
    font-size: 36px;
}

QLabel#MessageText {
    color: #FFFFFF;
    font-size: 28px;
}

QLabel#MessageReadout {
    color: #FFFFFF;
    font-size: 35px;
}

QLCDNumber#MessageLCD {
    background-color: #345475;
    color: #FFFFFF;
}

QPushButton#MessageConnectDisabled {
    color: #FFFFFF;
    background-color: #444444;
    border-radius: 5px;
    font-size: 22px;
}

QPushButton#MessageConnectGreen {
    color: #FFFFFF;
    background-color: #008966;
    border-radius: 5px;
    font-size: 22px;
}

QPushButton#MessageConnectRed {
    color: #FFFFFF;
    background-color: #d34739;
    border-radius: 5px;
    font-size: 22px;
}

QPushButton#MessageButton {
    color: #FFFFFF;
    background-color: #345475;
    font-size: 22px;
    border-radius: 5px;
}

QPushButton#MessageWarmup {
    color: #FFFFFF;
    background-color: #345475;
    border-radius: 5px;
    padding: 5px;
}

QPushButton#MessageWarmupDisabled {
    color: #000000;
    background-color: rgb(180, 180, 180);
    border-radius: 5px;
    padding: 5px;
}

QLabel#MessageWarmup {
    color: #FFFFFF;
}