QTableWidget#Macro {
    background-color: $main-background;
    @if $isPortrait {
        font-size: 22px;
    }
    @else {
        font-size: 16px;
    }
    color: #FFFFFF;
    gridline-color: #CCCCCC;
    border: 1px solid #CCCCCC;
}

QHeaderView::section#Macro {
    background-color: #AAAAAA;
    @if $isPortrait {
        font-size: 22px;
    }
    @else {
        font-size: 16px;
    }
    color: #000000;
    border: 1px solid black;
}