$statusbar-background: #666666;

QStatusBar#StatusBar {
    color: #FFFFFF;
    background: $statusbar-background;
}

QStatusBar::item#StatusBar {
    border: 0px;
}

QLabel#StatusBar {
    color: #FFFFFF;
    @if $isPortrait {
        font-size: 20px;
    }
    @else {
        font-size: 16px;
    }
}

QLabel#StatusBarWarning {
    color: #FFFFFF;
    background: $warning-color;
    @if $isPortrait {
        font-size: 20px;
    }
    @else {
        font-size: 16px;
    }
}

QLabel#StatusBarDanger {
    color: #FFFFFF;
    background: $danger-color;
    @if $isPortrait {
        font-size: 20px;
    }
    @else {
        font-size: 16px;
    }
}

QLabel#StatusBarOK {
    color: #FFFFFF;
    background: $ok-color;
    @if $isPortrait {
        font-size: 20px;
    }
    @else {
        font-size: 16px;
    }
}

QLabel#StatusBarReadout {
    color: #FFFFFF;
    background: #000000;
    @if $isPortrait {
        font-size: 20px;
    }
    @else {
        font-size: 16px;
    }
}

QLabel#StatusBarToolReadout {
    color: #FFFFFF;
    background: #000000;
    @if $isPortrait {
        font-size: 20px;
    }
    @else {
        font-size: 16px;
    }
}

QPushButton#StatusBarReadoutButton {
    color: #FFFFFF;
    background: #000000;
    @if $isPortrait {
        font-size: 20px;
    }
    @else {
        font-size: 16px;
    }
}

QPushButton#StatusBarWarning {
    color: #FFFFFF;
    background: $warning-color;
    @if $isPortrait {
        font-size: 20px;
    }
    @else {
        font-size: 16px;
    }
    text-align: center;
}

QPushButton#StatusBarOK {
    color: #FFFFFF;
    background: $ok-color;
    @if $isPortrait {
        font-size: 20px;
    }
    @else {
        font-size: 16px;
    }
    text-align: center;
}

QPushButton#StatusBarOK1 {
    color: #FFFFFF;
    background: $ok-color1;
    @if $isPortrait {
        font-size: 20px;
    }
    @else {
        font-size: 16px;
    }
    text-align: center;
}

QPushButton#StatusBarOK2 {
    color: #FFFFFF;
    background: $ok-color2;
    @if $isPortrait {
        font-size: 20px;
    }
    @else {
        font-size: 16px;
    }
    text-align: center;
}

QMenu#StatusbarMenu {
    background: #444444;
    spacing: 10px;
}

QPushButton#StatusBarMenuButton {
    margin: 10px 5px;
    background-color: #d34739;
    border-radius: 5px;
    font-size: 40px;
    text-align: left;
}