QWidget#Network{
    background-color: #222222;
}

QPushButton#Network {
    color: #FFFFFF;
    background-color: #345475;
    font-size: 26px;
    border-radius: 5px;
    min-height: 60px;
}

QPushButton#NetworkDisabled {
    color: #FFFFFF;
    background-color: #444444;
    font-size: 26px;
    border-radius: 5px;
    min-height: 60px;
}

QTreeView#Network {
    background-color: #444444;
    font-size: 26px;
    color: #FFFFFF;
}

QTreeView::item::selected#Network {
    color: #FF0000;
    border: 1px solid #000000;
}

QHeaderView::section#Network {
    background-color: #888888;
    color:#000000;
    font-size: 26px;
}

QLabel#Network {
    font-size: 26px;
    color: #FFFFFF;
}

QLabel#NetworkWarning {
    color: #FFFFFF;
    background: $warning-color;
    font-size: 26px;
}

QLabel#NetworkOK {
    color: #FFFFFF;
    background: $ok-color;
    font-size: 26px;
}