QLabel#MotorErrorHeader {
    color: #000000;
    background-color: #d34739;
    font-size: 48px;
}

QLabel#MotorErrorHeaderOK {
    color: #FFFFFF;
    font-size: 48px;
}

QLabel#MotorError {
    color: #FFFFFF;
    font-size: 32px;
}

QPushButton#MotorErrorDisabled {
    color: #FFFFFF;
    background-color: #444444;
    font-size: 28px;
    border-radius: 5px;
}

QPushButton#MotorErrorReady {
    color: #FFFFFF;
    background-color: #008966;
    font-size: 28px;
    border-radius: 5px;
}