QWidget#SdCard {
    background-color: $main-background;
}

QPushButton#SdCardButton {
    color: #FFFFFF;
    background-color: #345475;
    font-size: 26px;
    border-radius: 5px;
}

QPushButton#SdCardButtonDisabled {
    color: #FFFFFF;
    background-color: #444444;
    font-size: 26px;
    border-radius: 5px;
}

QTreeView#SdCard {
    background-color: #444444;
    font-size: 26px;
    color: #FFFFFF;
}

QTreeView::item::selected#SdCard {
    color: #FF0000;
    border: 1px solid #000000;
}

QHeaderView::section#SdCard {
    background-color: #888888;
    color:#000000;
    font-size: 26px;
}

QLabel#SdCard {
    font-size: 26px;
    color: #FFFFFF;
}