QTreeView#DirManager {
    background: #444444;
    @if $isPortrait {
        font-size: 36px;
        qproperty-indentation: 45;
    }
    @else {
        font-size: 25px;
        qproperty-indentation: 30;
    }
}

QTreeView::item#DirManager {
    color: #FFFFFF;
}

QListView::item#DirManager {
    color: #FFFFFF;
}

QTreeView::item::selected#DirManager {
    background-color: #345475;
}

QTreeView::branch::open::has-children#DirManager {
    border-image: none;
    image: url('res/branch-open.svg');
    @if $isPortrait {
        width: 36px;
        height: 36px;
    }
    @else {
        width: 25px;
        height: 25px;
    }
}

QTreeView::branch::closed::has-children#DirManager {
    border-image: none;
    image: url('res/branch-closed.svg');
    @if $isPortrait {
        width: 36px;
        height: 36px;
    }
    @else {
        width: 25px;
        height: 25px;
    }
}

#DirManager QHeaderView::section {
    @if $isPortrait {
        font-size: 32px;
    }
    @else {
        font-size: 20px;
    }
}

#DirManager QHeaderView::section {
    background-color: #333333;
    color: white;
}

QTreeView#DirManager ::horizontal-scrollbar {
    height: 50px;
}






QTreeView#FileManager {
    background: #444444;
    @if $isPortrait {
        font-size: 26px;
        qproperty-indentation: 45;
    }
    @else {
        font-size: 25px;
        qproperty-indentation: 30;
    }
}

QTreeView::item#FileManager {
    color: #FFFFFF;
}

QListView::item#FileManager {
    color: #FFFFFF;
}

QTreeView::item::selected#FileManager {
    background-color: #345475;
}

QTreeView::branch::open::has-children#FileManager {
    border-image: none;
    image: url('res/branch-open.svg');
    @if $isPortrait {
        width: 36px;
        height: 36px;
    }
    @else {
        width: 25px;
        height: 25px;
    }
}

QTreeView::branch::closed::has-children#FileManager {
    border-image: none;
    image: url('res/branch-closed.svg');
    @if $isPortrait {
        width: 36px;
        height: 36px;
    }
    @else {
        width: 25px;
        height: 25px;
    }
}

#FileManager QHeaderView::section {
    @if $isPortrait {
        font-size: 32px;
    }
    @else {
        font-size: 20px;
    }
}

#FileManager QHeaderView::section {
    background-color: #333333;
    color: white;
}

QTreeView#FileManager::horizontal-scrollbar {
    height: 50px;
}
