QProgressBar#Torque {
    color: #FFFFFF;
    text-align: center;
    @if $isPortrait {
        font-size: 32px;
        height: 60px;
    }
    @else {
        font-size: 16px;
        height: 22px;
    }
    background-color: #444444;
    border: 2px solid white;
    border-radius: 5px;
    margin: 0.5px;
    
}

QProgressBar::chunk#Torque {
    background-color: green;
}

QLabel#SpindleTitle {
    color: #FFFFFF;
}

QLabel#SpindleSubtitle {
    color: #FFFFFF;
}

QPushButton#SpindleButton {
    color: #FFFFFF;
    background-color: #345475;
    border-radius: 5px;
    padding: 5px;
    font-size: 30px;
    min-height: 60px;
    min-width: 60px;
    text-align: center;
}