QToolBar {
    background-color: #444444;
    spacing: 10px;
}

QToolBar#PlotToolbar {
    background-color: #444444;
    spacing: 10px;
    border: none;
}

QLabel#ToolbarButton {
    background-color: transparent;
    border: none;
    text-align: left;
}   

QPushButton#ToolbarButton {
    background-color: #AAAAAA;
    border-radius: 5px;
    text-align: left;
}

QPushButton#ToolbarButtonDisabled {
    margin: 10px 5px;
    background-color:rgb(80, 80, 80);
    border-radius: 5px;
    font-size: 40px;
    text-align: left;
}

QPushButton#ToolbarButtonWarning {
    margin: 5px 5px;
    background-color: #c07b0e;
    border-radius: 5px;
    font-size: 40px;
}

QPushButton#ToolbarButtonDanger {
    background-color: #d34739;
    border-radius: 5px;
    text-align: left;
}

QPushButton#ToolbarButtonGreen {
    background-color: #008966;
    border-radius: 5px;
    text-align: left;
}

QPushButton#ToolbarMenuButton {
    margin: 10px 5px;
    background-color: #AAAAAA;
    border-radius: 5px;
    text-align: left;
}

QPushButton#ToolbarSubMenuButton {
    margin: 10px 5px;
    background-color: #AAAAAA;
    border-radius: 5px;
    text-align: left;
    font-size: 40px;
}

QPushButton#ToolbarSubMenuButtonGreen {
    margin: 10px 5px;
    background-color: #008966;
    border-radius: 5px;
    text-align: left;
    font-size: 40px;
}

QMenu#ToolbarMenu {
    background: #444444;
    spacing: 10px;
}

QFrame#Sidebar {
    background-color: #444444;
}