QCheckBox#Settings {
    color: #FFFFFF;
    @if $isPortrait {
        font_size: 22px;
    }
}

QCheckBox::indicator::unchecked#Settings {
    image: url('res/check_empty.png');

    @if $isPortrait {
        width: 40px;
        height: 40px;
    }

    @else {
        width: 20px;
        height: 20px;
    }
}

QCheckBox::indicator::checked#Settings {
    image: url('res/checked.png');

    @if $isPortrait {
        width: 40px;
        height: 40px;
    }

    @else {
        width: 20px;
        height: 20px;
    }
}

QRadioButton#Settings {
    color: #FFFFFF;
    @if $isPortrait {
        font-size: 22px;
    }
    @else {
        font-size: 16px;
    }
}

QRadioButton::indicator::unchecked#Settings {
    image: url('res/check_empty.png');

    @if $isPortrait {
        width: 40px;
        height: 40px;
    }

    @else {
        width: 20px;
        height: 20px;
    }
}

QRadioButton::indicator::checked#Settings {
    image: url('res/checked.png');

    @if $isPortrait {
        width: 40px;
        height: 40px;
    }

    @else {
        width: 20px;
        height: 20px;
    }
}

QLabel#Settings {
    color: #FFFFFF;
}

QLabel#SettingsDanger {
    color: #FF0000;
}

QPushButton#Settings {
    color: #FFFFFF;
    background-color: #345475;
    border-radius: 5px;
    padding: 5px;
}

QPushButton#SettingsModified {
    color: #FFFFFF;
    background-color: rgb(0, 255, 42);
    border-radius: 5px;
    padding: 5px;
}

QPushButton#SettingsDisabled {
    color: #FFFFFF;
    background-color: rgb(180, 180, 180);
    border-radius: 5px;
    padding: 5px;
}

QComboBox#Settings {
    color: #FFFFFF;
    background: #345475;
    text-align: center;
    border: 1px solid gray;
}

QComboBox QAbstractItemView {
    color: #FFFFFF;
    padding: 10px 10px;
    border: 0px solid #FFFFFF;
    border-radius: 10px; /* was 0px */
    background-color:rgb(67, 117, 133);
    selection-background-color:rgb(27, 45, 63);
}

QComboBox::drop-down {
    @if $isPortrait {
        width: 60px;
        height: 60px;
    }
}

QComboBox QAbstractItemView::item {
    @if $isPortrait {
        min-height: 50px;
    }
}

QComboBox QAbstractItemView:hover {
  color: #FFFFFF;
}

QComboBox QAbstractItemView QScrollBar:vertical {
    @if $isPortrait {
        width: 60px;
    }
    @else {
        width: 20px;
    }
}

QComboBox QAbstractItemView QScrollBar::handle:vertical {
    @if $isPortrait {
        min-height: 60px;
    }
    @else {
        min-height: 20px;
    } 
}

QTableWidget#Settings {
    background-color: $main-background;
    color: #FFFFFF;
    gridline-color: #CCCCCC;
    border: 1px solid #CCCCCC;
}

QTableView#Settings {
    background-color: $main-background;
    color: #FFFFFF;
    gridline-color: #CCCCCC;
    border: 1px solid #CCCCCC;
}

QHeaderView::section#Settings {
    background-color: #AAAAAA;
    color: #000000;
    border: 1px solid black;
}

QGroupBox#Settings {
    color: #FFFFFF;
    background-color: #222222;
    border: 3px solid white;
    border-radius: 5px;
    padding: 0px 0px 0px 0px;
    margin-top: 20px;
}

