QLabel#StatusLabel {
    color: #FFFFFF;
    background-color: #444444;
}

QLabel#StatusFlashPrimary {
    color: #000000;
    background-color: #dd2909;
}

QLabel#StatusFlashSecondary {
    color: #000000;
    background-color: #ecff44;
}

QLabel#StatusReady {
    color: #000000;
    background-color: #008966;
}

QLabel#StatusBusy {
    color: #000000;
    background-color: #ADB5BD;
}

QLabel#StatusReadout {
    color: #000000;
    background-color: #ADB5BD;
}

QLabel#StatusNumericReadout {
    color: #000000;
    background-color: #ADB5BD;
}

QPushButton#StatusNumericReadout {
    color: #000000;
    background-color: #ADB5BD;
}

QPushButton#StatusNumericReadoutOK {
    color: #000000;
    background-color: #008966;;
}

QLabel#StatusNumericReadoutWarning {
    color: #000000;
    background-color: #dd2909;
}

QPushButton#StatusNumericReadoutWarning {
    color: #000000;
    background-color: #dd2909;
}

QPushButton#StatusButton {
    background-color: #AAAAAA;
    border-radius: 5px;
}

QPushButton#StatusButtonOK {
    background-color: #008966;
    border-radius: 5px;
}

QPushButton#StatusButtonWarning {
    background-color: $warning-color;
    border-radius: 5px;
}

QPushButton#StatusButtonDisabled {
    background-color:#cca970;
    border-radius: 5px;
}

