$loadfile-font-size: 30px;

QLabel#LoadFileLabel {
    color: #FFFFFF;
    font-size: $loadfile-font-size;
}

QProgressBar#LoadFileProgressBar {
    color: #FFFFFF;
    background-color: #222222;
    text-align: center;
    border: 2px solid white;
    border-radius: 5px;
    margin: 0.5px;
    font-size: $loadfile-font-size;
    min-width: 600px;
}

QProgressBar::chunk#LoadFileProgressBar {
    background-color: #345475;
}

QPushButton#LoadFileButton {
    color: #FFFFFF;
    background-color: #345475;
    border-radius: 5px;
    padding: 5px;
    font-size: $loadfile-font-size;
    min-height: 60px;
    min-width: 60px;
}