
var wimp = (() => {
  var _scriptName = typeof document != 'undefined' ? document.currentScript?.src : undefined;
  
  return (
function(moduleArg = {}) {
  var moduleRtn;

function c(){g.buffer!=k.buffer&&p();return k}function q(){g.buffer!=k.buffer&&p();return aa}function t(){g.buffer!=k.buffer&&p();return ba}function u(){g.buffer!=k.buffer&&p();return ca}function v(){g.buffer!=k.buffer&&p();return da}var w=moduleArg,ea,fa,ha=new Promise((a,b)=>{ea=a;fa=b}),ia="object"==typeof window,ja="function"==typeof importScripts,ka=w.$ww,la=Object.assign({},w),x="";function ma(a){return w.locateFile?w.locateFile(a,x):x+a}var na,oa;
if(ia||ja)ja?x=self.location.href:"undefined"!=typeof document&&document.currentScript&&(x=document.currentScript.src),_scriptName&&(x=_scriptName),x.startsWith("blob:")?x="":x=x.substr(0,x.replace(/[?#].*/,"").lastIndexOf("/")+1),ja&&(oa=a=>{var b=new XMLHttpRequest;b.open("GET",a,!1);b.responseType="arraybuffer";b.send(null);return new Uint8Array(b.response)}),na=a=>fetch(a,{credentials:"same-origin"}).then(b=>b.ok?b.arrayBuffer():Promise.reject(Error(b.status+" : "+b.url)));
var pa=console.log.bind(console),y=console.error.bind(console);Object.assign(w,la);la=null;var g,qa,ra=!1,sa,k,aa,ta,ua,ba,ca,da;function p(){var a=g.buffer;k=new Int8Array(a);ta=new Int16Array(a);aa=new Uint8Array(a);ua=new Uint16Array(a);ba=new Int32Array(a);ca=new Uint32Array(a);da=new Float32Array(a);new Float64Array(a)}w.wasmMemory?g=w.wasmMemory:g=new WebAssembly.Memory({initial:256,maximum:32768,shared:!0});p();var va=[],wa=[],xa=[];
function ya(){ka?(za=1,Aa(w.sb,w.sz),removeEventListener("message",Ba),Ca=Ca.forEach(Da),addEventListener("message",Da)):Ea(wa)}var z=0,Fa=null,A=null;function Ga(a){a="Aborted("+a+")";y(a);ra=!0;a=new WebAssembly.RuntimeError(a+". Build with -sASSERTIONS for more info.");fa(a);throw a;}var Ha=a=>a.startsWith("data:application/octet-stream;base64,"),Ia;
function Ja(a){return na(a).then(b=>new Uint8Array(b),()=>{if(oa)var b=oa(a);else throw"both async and sync fetching of the wasm failed";return b})}function Ka(a,b,d){return Ja(a).then(e=>WebAssembly.instantiate(e,b)).then(d,e=>{y(`failed to asynchronously prepare wasm: ${e}`);Ga(e)})}
function La(a,b){var d=Ia;return"function"!=typeof WebAssembly.instantiateStreaming||Ha(d)||"function"!=typeof fetch?Ka(d,a,b):fetch(d,{credentials:"same-origin"}).then(e=>WebAssembly.instantiateStreaming(e,a).then(b,function(f){y(`wasm streaming compile failed: ${f}`);y("falling back to ArrayBuffer instantiation");return Ka(d,a,b)}))}function Ma(a){this.name="ExitStatus";this.message=`Program terminated with exit(${a})`;this.status=a}
var Ca=[],Na=a=>{if(!(a instanceof Ma||"unwind"==a))throw a;},Oa=0,Pa=a=>{sa=a;za||0<Oa||(ra=!0);throw new Ma(a);},Qa=a=>{if(!ra)try{if(a(),!(za||0<Oa))try{sa=a=sa,Pa(a)}catch(b){Na(b)}}catch(b){Na(b)}},B,Da=a=>{let b=a.data,d=b._wsc;d&&Qa(()=>B.get(d)(...b.x))},Ba=a=>{Ca.push(a)},Ea=a=>{a.forEach(b=>b(w))},za=w.noExitRuntime||!0;class Ra{constructor(a){this.s=a-24}}
var Sa=0,Ta=0,Ua="undefined"!=typeof TextDecoder?new TextDecoder:void 0,Va=(a,b=0,d=NaN)=>{var e=b+d;for(d=b;a[d]&&!(d>=e);)++d;if(16<d-b&&a.buffer&&Ua)return Ua.decode(a.slice(b,d));for(e="";b<d;){var f=a[b++];if(f&128){var h=a[b++]&63;if(192==(f&224))e+=String.fromCharCode((f&31)<<6|h);else{var l=a[b++]&63;f=224==(f&240)?(f&15)<<12|h<<6|l:(f&7)<<18|h<<12|l<<6|a[b++]&63;65536>f?e+=String.fromCharCode(f):(f-=65536,e+=String.fromCharCode(55296|f>>10,56320|f&1023))}}else e+=String.fromCharCode(f)}return e},
C=(a,b)=>a?Va(q(),a,b):"",D={},Wa=1,Xa={},E=(a,b,d)=>{var e=q();if(0<d){var f=b;d=b+d-1;for(var h=0;h<a.length;++h){var l=a.charCodeAt(h);if(55296<=l&&57343>=l){var m=a.charCodeAt(++h);l=65536+((l&1023)<<10)|m&1023}if(127>=l){if(b>=d)break;e[b++]=l}else{if(2047>=l){if(b+1>=d)break;e[b++]=192|l>>6}else{if(65535>=l){if(b+2>=d)break;e[b++]=224|l>>12}else{if(b+3>=d)break;e[b++]=240|l>>18;e[b++]=128|l>>12&63}e[b++]=128|l>>6&63}e[b++]=128|l&63}}e[b]=0;a=b-f}else a=0;return a},F,Ya=a=>{var b=a.getExtension("ANGLE_instanced_arrays");
b&&(a.vertexAttribDivisor=(d,e)=>b.vertexAttribDivisorANGLE(d,e),a.drawArraysInstanced=(d,e,f,h)=>b.drawArraysInstancedANGLE(d,e,f,h),a.drawElementsInstanced=(d,e,f,h,l)=>b.drawElementsInstancedANGLE(d,e,f,h,l))},Za=a=>{var b=a.getExtension("OES_vertex_array_object");b&&(a.createVertexArray=()=>b.createVertexArrayOES(),a.deleteVertexArray=d=>b.deleteVertexArrayOES(d),a.bindVertexArray=d=>b.bindVertexArrayOES(d),a.isVertexArray=d=>b.isVertexArrayOES(d))},$a=a=>{var b=a.getExtension("WEBGL_draw_buffers");
b&&(a.drawBuffers=(d,e)=>b.drawBuffersWEBGL(d,e))},ab=a=>{a.ba=a.getExtension("WEBGL_draw_instanced_base_vertex_base_instance")},bb=a=>{a.ca=a.getExtension("WEBGL_multi_draw_instanced_base_vertex_base_instance")},cb=a=>{var b="ANGLE_instanced_arrays EXT_blend_minmax EXT_disjoint_timer_query EXT_frag_depth EXT_shader_texture_lod EXT_sRGB OES_element_index_uint OES_fbo_render_mipmap OES_standard_derivatives OES_texture_float OES_texture_half_float OES_texture_half_float_linear OES_vertex_array_object WEBGL_color_buffer_float WEBGL_depth_texture WEBGL_draw_buffers EXT_color_buffer_float EXT_conservative_depth EXT_disjoint_timer_query_webgl2 EXT_texture_norm16 NV_shader_noperspective_interpolation WEBGL_clip_cull_distance EXT_clip_control EXT_color_buffer_half_float EXT_depth_clamp EXT_float_blend EXT_polygon_offset_clamp EXT_texture_compression_bptc EXT_texture_compression_rgtc EXT_texture_filter_anisotropic KHR_parallel_shader_compile OES_texture_float_linear WEBGL_blend_func_extended WEBGL_compressed_texture_astc WEBGL_compressed_texture_etc WEBGL_compressed_texture_etc1 WEBGL_compressed_texture_s3tc WEBGL_compressed_texture_s3tc_srgb WEBGL_debug_renderer_info WEBGL_debug_shaders WEBGL_lose_context WEBGL_multi_draw WEBGL_polygon_mode".split(" ");
return(a.getSupportedExtensions()||[]).filter(d=>b.includes(d))},db=1,G=[],H=[],eb=[],I=[],J=[],K=[],fb=[],L=[],M=[],gb=[],hb={},ib={},jb=4,kb=0,N=a=>{for(var b=db++,d=a.length;d<b;d++)a[d]=null;return b},lb=(a,b,d,e)=>{for(var f=0;f<a;f++){var h=F[d](),l=h&&N(e);h?(h.name=l,e[l]=h):O||=1282;t()[b+4*f>>2]=l}},nb=a=>{var b={J:2,alpha:!0,depth:!0,stencil:!0,antialias:!1,premultipliedAlpha:!0,preserveDrawingBuffer:!1,powerPreference:"default",failIfMajorPerformanceCaveat:!1,H:!0};a.s||(a.s=a.getContext,
a.getContext=function(e,f){f=a.s(e,f);return"webgl"==e==f instanceof WebGLRenderingContext?f:null});var d=1<b.J?a.getContext("webgl2",b):a.getContext("webgl",b);return d?mb(d,b):0},mb=(a,b)=>{var d=N(L),e={handle:d,attributes:b,version:b.J,m:a};a.canvas&&(a.canvas.M=e);L[d]=e;("undefined"==typeof b.H||b.H)&&ob(e);return d},ob=a=>{a||=P;if(!a.S){a.S=!0;var b=a.m;b.U=b.getExtension("WEBGL_multi_draw");b.P=b.getExtension("EXT_polygon_offset_clamp");b.O=b.getExtension("EXT_clip_control");b.Z=b.getExtension("WEBGL_polygon_mode");
Ya(b);Za(b);$a(b);ab(b);bb(b);2<=a.version&&(b.o=b.getExtension("EXT_disjoint_timer_query_webgl2"));if(2>a.version||!b.o)b.o=b.getExtension("EXT_disjoint_timer_query");cb(b).forEach(d=>{d.includes("lose_context")||d.includes("debug")||b.getExtension(d)})}},O,P,pb=(a,b)=>{F.bindFramebuffer(a,eb[b])},qb=a=>F.clear(a),rb=(a,b,d,e)=>F.clearColor(a,b,d,e),sb=a=>F.clearStencil(a),tb=(a,b)=>{u()[a>>2]=b;var d=u()[a>>2];u()[a+4>>2]=(b-d)/4294967296};
function ub(){var a=cb(F);return a=a.concat(a.map(b=>"GL_"+b))}
var vb=(a,b,d)=>{if(b){var e=void 0;switch(a){case 36346:e=1;break;case 36344:0!=d&&1!=d&&(O||=1280);return;case 34814:case 36345:e=0;break;case 34466:var f=F.getParameter(34467);e=f?f.length:0;break;case 33309:if(2>P.version){O||=1282;return}e=ub().length;break;case 33307:case 33308:if(2>P.version){O||=1280;return}e=33307==a?3:0}if(void 0===e)switch(f=F.getParameter(a),typeof f){case "number":e=f;break;case "boolean":e=f?1:0;break;case "string":O||=1280;return;case "object":if(null===f)switch(a){case 34964:case 35725:case 34965:case 36006:case 36007:case 32873:case 34229:case 36662:case 36663:case 35053:case 35055:case 36010:case 35097:case 35869:case 32874:case 36389:case 35983:case 35368:case 34068:e=
0;break;default:O||=1280;return}else{if(f instanceof Float32Array||f instanceof Uint32Array||f instanceof Int32Array||f instanceof Array){for(a=0;a<f.length;++a)switch(d){case 0:t()[b+4*a>>2]=f[a];break;case 2:v()[b+4*a>>2]=f[a];break;case 4:c()[b+a]=f[a]?1:0}return}try{e=f.name|0}catch(h){O||=1280;y(`GL_INVALID_ENUM in glGet${d}v: Unknown object returned from WebGL getParameter(${a})! (error: ${h})`);return}}break;default:O||=1280;y(`GL_INVALID_ENUM in glGet${d}v: Native code calling glGet${d}v(${a}) and it returns ${f} of type ${typeof f}!`);
return}switch(d){case 1:tb(b,e);break;case 0:t()[b>>2]=e;break;case 2:v()[b>>2]=e;break;case 4:c()[b]=e?1:0}}else O||=1281},wb=(a,b)=>vb(a,b,0),xb=a=>{a-=5120;0==a?a=c():1==a?a=q():2==a?(g.buffer!=k.buffer&&p(),a=ta):4==a?a=t():6==a?a=v():5==a||28922==a||28520==a||30779==a||30782==a?a=u():(g.buffer!=k.buffer&&p(),a=ua);return a},yb=(a,b,d,e,f)=>{a=xb(a);b=e*((kb||d)*({5:3,6:4,8:2,29502:3,29504:4,26917:2,26918:2,29846:3,29847:4}[b-6402]||1)*a.BYTES_PER_ELEMENT+jb-1&-jb);return a.subarray(f>>>31-Math.clz32(a.BYTES_PER_ELEMENT),
f+b>>>31-Math.clz32(a.BYTES_PER_ELEMENT))},zb=(a,b,d,e,f,h,l)=>{if(2<=P.version)if(F.D)F.readPixels(a,b,d,e,f,h,l);else{var m=xb(h);l>>>=31-Math.clz32(m.BYTES_PER_ELEMENT);F.readPixels(a,b,d,e,f,h,m,l)}else(m=yb(h,f,d,e,l))?F.readPixels(a,b,d,e,f,h,m):O||=1280},Ab=()=>{Ga("Cannot use convertFrameToPC (needed by __builtin_return_address) without -sUSE_OFFSET_CONVERTER");return 0},R={},Bb=a=>{a.forEach(b=>{var d=Ab();d&&(R[d]=b)})},Cb={},Eb=()=>{if(!Db){var a={USER:"web_user",LOGNAME:"web_user",PATH:"/",
PWD:"/",HOME:"/home/web_user",LANG:("object"==typeof navigator&&navigator.languages&&navigator.languages[0]||"C").replace("-","_")+".UTF-8",_:"./this.program"},b;for(b in Cb)void 0===Cb[b]?delete a[b]:a[b]=Cb[b];var d=[];for(b in a)d.push(`${b}=${a[b]}`);Db=d}return Db},Db,Fb=[null,[],[]],Hb=a=>{for(var b=0,d=0;d<a.length;++d){var e=a.charCodeAt(d);127>=e?b++:2047>=e?b+=2:55296<=e&&57343>=e?(b+=4,++d):b+=3}b+=1;(d=Gb(b))&&E(a,d,b);return d},Ib=a=>"]"==a.slice(-1)&&a.lastIndexOf("["),S=a=>{var b=F.N;
if(b){var d=b.u[a];"number"==typeof d&&(b.u[a]=d=F.getUniformLocation(b,b.K[a]+(0<d?`[${d}]`:"")));return d}O||=1282},T=[];function Jb(){}function Kb(){}function Lb(){}function Mb(){}function Nb(){}function Ob(){}function Pb(){}function Qb(){}function Rb(){}function Sb(){}function Tb(){}function Ub(){}function Vb(){}function Wb(){}function Xb(){}function Yb(){}function Zb(){}function $b(){}function ac(){}function bc(){}function cc(){}function dc(){}function ec(){}function U(){}function fc(){}
function gc(){}var V,hc=[],jc=a=>ic(a);w.stackAlloc=jc;ka&&(D[0]=this,addEventListener("message",Ba));for(var kc=new Float32Array(288),lc=0;288>=lc;++lc)T[lc]=kc.subarray(0,lc);
(function(){if(w.skwasmSingleThreaded){Yb=function(){return!0};let e;Kb=function(f,h){e=h};Lb=function(){return performance.now()};U=function(f){queueMicrotask(()=>e(f))}}else{Yb=function(){return!1};let e=0;Kb=function(f,h){function l({data:m}){const n=m.l;n&&("syncTimeOrigin"==n?e=performance.timeOrigin-m.timeOrigin:h(m))}f?(D[f].addEventListener("message",l),D[f].postMessage({l:"syncTimeOrigin",timeOrigin:performance.timeOrigin})):addEventListener("message",l)};Lb=function(){return performance.now()+
e};U=function(f,h,l){l?D[l].postMessage(f,{transfer:h}):postMessage(f,{transfer:h})}}const a=new Map,b=new Map,d=new Map;Mb=function(e){Kb(e,function(f){var h=f.l;if(h)switch(h){case "transferCanvas":mc(f.g,f.canvas,f.h);break;case "onInitialized":nc(f.g,f.h);break;case "resizeSurface":oc(f.g,f.width,f.height,f.h);break;case "onResizeComplete":pc(f.g,f.h);break;case "triggerContextLoss":qc(f.g,f.h);break;case "onContextLossTriggered":rc(f.g,f.h);break;case "reportContextLost":sc(f.g,f.h);break;case "renderPictures":tc(f.g,
f.W,f.V,f.h,Lb());break;case "onRenderComplete":uc(f.g,f.h,{imageBitmaps:f.R,rasterStartMilliseconds:f.Y,rasterEndMilliseconds:f.X});break;case "setAssociatedObject":d.set(f.F,f.object);break;case "disposeAssociatedObject":f=f.F;h=d.get(f);h.close&&h.close();d.delete(f);break;case "disposeSurface":vc(f.g);break;case "rasterizeImage":wc(f.g,f.image,f.format,f.h);break;case "onRasterizeComplete":xc(f.g,f.data,f.h);break;default:console.warn(`unrecognized skwasm message: ${h}`)}})};fc=function(e,f,h){U({l:"setAssociatedObject",
F:f,object:h},[h],e)};Wb=function(e){return d.get(e)};Vb=function(e,f){U({l:"disposeAssociatedObject",F:f},[],e)};Pb=function(e,f){U({l:"disposeSurface",g:f},[],e)};Tb=function(e,f,h,l){U({l:"transferCanvas",g:f,canvas:h,h:l},[h],e)};bc=function(e,f,h){U({l:"onInitialized",g:e,$:f,h},[])};Sb=function(e,f,h,l,m){U({l:"resizeSurface",g:f,width:h,height:l,h:m},[],e)};cc=function(e,f){U({l:"onResizeComplete",g:e,h:f},[])};dc=function(e,f,h){e=b.get(e);e.width=f;e.height=h};Rb=function(e,f,h,l,m){U({l:"renderPictures",
g:f,W:h,V:l,h:m},[],e)};ec=async function(e,f,h,l){f||=[];U({l:"onRenderComplete",g:e,h:l,R:f,Y:h,X:Lb()},[...f])};Jb=function(e,f){f||=[];e=b.get(e);f.push(e.transferToImageBitmap());return f};Qb=function(e,f,h,l,m){U({l:"rasterizeImage",g:f,image:h,format:l,h:m},[],e)};Zb=function(e,f,h){U({l:"onRasterizeComplete",g:e,data:f,h})};Ub=function(e,f,h){U({l:"triggerContextLoss",g:f,h},[],e)};$b=function(e,f){U({l:"onContextLossTriggered",g:e,h:f},[])};ac=function(e,f){U({l:"reportContextLost",g:e,h:f},
[])};gc=function(){P.m.getExtension("WEBGL_lose_context").loseContext()};Xb=function(e,f){const h=nb(e);b.set(h,e);var l=function(m){m.preventDefault();yc(f);e.removeEventListener("webglcontextlost",l)};e.addEventListener("webglcontextlost",l);a.set(h,l);return h};Ob=function(e){const f=b.get(e),h=a.get(e);f&&h&&f.removeEventListener("webglcontextlost",h);P===L[e]&&(P=null);"object"==typeof JSEvents&&JSEvents.da(L[e].m.canvas);L[e]&&L[e].m.canvas&&(L[e].m.canvas.M=void 0);L[e]=null;b.delete(e);a.delete(e)};
Nb=function(e,f,h){const l=P.m,m=l.createTexture();l.bindTexture(l.TEXTURE_2D,m);l.pixelStorei(l.UNPACK_PREMULTIPLY_ALPHA_WEBGL,!0);l.texImage2D(l.TEXTURE_2D,0,l.RGBA,f,h,0,l.RGBA,l.UNSIGNED_BYTE,e);l.pixelStorei(l.UNPACK_PREMULTIPLY_ALPHA_WEBGL,!1);l.bindTexture(l.TEXTURE_2D,null);e=N(J);J[e]=m;return e}})();
var Jc={__cxa_throw:(a,b,d)=>{var e=new Ra(a);u()[e.s+16>>2]=0;u()[e.s+4>>2]=b;u()[e.s+8>>2]=d;Sa=a;Ta++;throw Sa;},__syscall_fcntl64:function(){return 0},__syscall_fstat64:()=>{},__syscall_ioctl:function(){return 0},__syscall_openat:function(){},_abort_js:()=>{Ga("")},_emscripten_create_wasm_worker:(a,b)=>{let d=D[Wa]=new Worker(ma("wimp.ww.js"));d.postMessage({$ww:Wa,wasm:qa,js:w.mainScriptUrlOrBlob||_scriptName,wasmMemory:g,sb:a,sz:b});d.onmessage=Da;return Wa++},_emscripten_get_now_is_monotonic:()=>
1,_emscripten_runtime_keepalive_clear:()=>{za=!1;Oa=0},_emscripten_throw_longjmp:()=>{throw Infinity;},_mmap_js:function(){return-52},_munmap_js:function(){},_setitimer_js:(a,b)=>{Xa[a]&&(clearTimeout(Xa[a].id),delete Xa[a]);if(!b)return 0;var d=setTimeout(()=>{delete Xa[a];Qa(()=>zc(a,performance.now()))},b);Xa[a]={id:d,ea:b};return 0},_tzset_js:(a,b,d,e)=>{var f=(new Date).getFullYear(),h=(new Date(f,0,1)).getTimezoneOffset();f=(new Date(f,6,1)).getTimezoneOffset();var l=Math.max(h,f);u()[a>>2]=
60*l;t()[b>>2]=Number(h!=f);b=m=>{var n=Math.abs(m);return`UTC${0<=m?"-":"+"}${String(Math.floor(n/60)).padStart(2,"0")}${String(n%60).padStart(2,"0")}`};a=b(h);b=b(f);f<h?(E(a,d,17),E(b,e,17)):(E(a,e,17),E(b,d,17))},emscripten_console_warn:a=>{console.warn(C(a))},emscripten_date_now:()=>Date.now(),emscripten_errn:(a,b)=>y(C(a,b)),emscripten_get_now:()=>performance.now(),emscripten_glBindFramebuffer:pb,emscripten_glClear:qb,emscripten_glClearColor:rb,emscripten_glClearStencil:sb,emscripten_glGetIntegerv:wb,
emscripten_glReadPixels:zb,emscripten_resize_heap:a=>{var b=q().length;a>>>=0;if(a<=b||2147483648<a)return!1;for(var d=1;4>=d;d*=2){var e=b*(1+.2/d);e=Math.min(e,a+100663296);a:{e=(Math.min(2147483648,65536*Math.ceil(Math.max(a,e)/65536))-g.buffer.byteLength+65535)/65536|0;try{g.grow(e);p();var f=1;break a}catch(h){}f=void 0}if(f)return!0}return!1},emscripten_stack_snapshot:function(){var a=Error().stack.toString().split("\n");"Error"==a[0]&&a.shift();Bb(a);R.I=Ab();R.T=a;return R.I},emscripten_stack_unwind_buffer:(a,
b,d)=>{if(R.I==a)var e=R.T;else e=Error().stack.toString().split("\n"),"Error"==e[0]&&e.shift(),Bb(e);for(var f=3;e[f]&&Ab()!=a;)++f;for(a=0;a<d&&e[a+f];++a)t()[b+4*a>>2]=Ab();return a},emscripten_wasm_worker_post_function_v:(a,b)=>{D[a].postMessage({_wsc:b,x:[]})},emscripten_webgl_enable_extension:function(a,b){a=L[a];b=C(b);b.startsWith("GL_")&&(b=b.substr(3));"ANGLE_instanced_arrays"==b&&Ya(F);"OES_vertex_array_object"==b&&Za(F);"WEBGL_draw_buffers"==b&&$a(F);"WEBGL_draw_instanced_base_vertex_base_instance"==
b&&ab(F);"WEBGL_multi_draw_instanced_base_vertex_base_instance"==b&&bb(F);"WEBGL_multi_draw"==b&&(F.U=F.getExtension("WEBGL_multi_draw"));"EXT_polygon_offset_clamp"==b&&(F.P=F.getExtension("EXT_polygon_offset_clamp"));"EXT_clip_control"==b&&(F.O=F.getExtension("EXT_clip_control"));"WEBGL_polygon_mode"==b&&(F.Z=F.getExtension("WEBGL_polygon_mode"));return!!a.m.getExtension(b)},emscripten_webgl_make_context_current:a=>{P=L[a];w.aa=F=P?.m;return!a||F?0:-5},environ_get:(a,b)=>{var d=0;Eb().forEach((e,
f)=>{var h=b+d;f=u()[a+4*f>>2]=h;for(h=0;h<e.length;++h)c()[f++]=e.charCodeAt(h);c()[f]=0;d+=e.length+1});return 0},environ_sizes_get:(a,b)=>{var d=Eb();u()[a>>2]=d.length;var e=0;d.forEach(f=>e+=f.length+1);u()[b>>2]=e;return 0},fd_close:()=>52,fd_pread:function(){return 52},fd_read:()=>52,fd_seek:function(){return 70},fd_write:(a,b,d,e)=>{for(var f=0,h=0;h<d;h++){var l=u()[b>>2],m=u()[b+4>>2];b+=8;for(var n=0;n<m;n++){var r=q()[l+n],Q=Fb[a];0===r||10===r?((1===a?pa:y)(Va(Q)),Q.length=0):Q.push(r)}f+=
m}u()[e>>2]=f;return 0},glActiveTexture:a=>F.activeTexture(a),glAttachShader:(a,b)=>{F.attachShader(H[a],K[b])},glBeginQueryEXT:(a,b)=>{F.o.beginQueryEXT(a,M[b])},glBindAttribLocation:(a,b,d)=>{F.bindAttribLocation(H[a],b,C(d))},glBindBuffer:(a,b)=>{35051==a?F.D=b:35052==a&&(F.v=b);F.bindBuffer(a,G[b])},glBindBufferRange:(a,b,d,e,f)=>{F.bindBufferRange(a,b,G[d],e,f)},glBindFramebuffer:pb,glBindRenderbuffer:(a,b)=>{F.bindRenderbuffer(a,I[b])},glBindTexture:(a,b)=>{F.bindTexture(a,J[b])},glBindVertexArray:a=>
{F.bindVertexArray(fb[a])},glBlendEquationSeparate:(a,b)=>F.blendEquationSeparate(a,b),glBlendFuncSeparate:(a,b,d,e)=>F.blendFuncSeparate(a,b,d,e),glBlitFramebuffer:(a,b,d,e,f,h,l,m,n,r)=>F.blitFramebuffer(a,b,d,e,f,h,l,m,n,r),glBufferData:(a,b,d,e)=>{2<=P.version?d&&b?F.bufferData(a,q(),e,d,b):F.bufferData(a,b,e):F.bufferData(a,d?q().subarray(d,d+b):b,e)},glBufferSubData:(a,b,d,e)=>{2<=P.version?d&&F.bufferSubData(a,b,q(),e,d):F.bufferSubData(a,b,q().subarray(e,e+d))},glCheckFramebufferStatus:a=>
F.checkFramebufferStatus(a),glClear:qb,glClearColor:rb,glClearDepthf:a=>F.clearDepth(a),glClearStencil:sb,glColorMask:(a,b,d,e)=>{F.colorMask(!!a,!!b,!!d,!!e)},glCompileShader:a=>{F.compileShader(K[a])},glCreateProgram:()=>{var a=N(H),b=F.createProgram();b.name=a;b.C=b.A=b.B=0;b.G=1;H[a]=b;return a},glCreateShader:a=>{var b=N(K);K[b]=F.createShader(a);return b},glCullFace:a=>F.cullFace(a),glDeleteBuffers:(a,b)=>{for(var d=0;d<a;d++){var e=t()[b+4*d>>2],f=G[e];f&&(F.deleteBuffer(f),f.name=0,G[e]=null,
e==F.D&&(F.D=0),e==F.v&&(F.v=0))}},glDeleteFramebuffers:(a,b)=>{for(var d=0;d<a;++d){var e=t()[b+4*d>>2],f=eb[e];f&&(F.deleteFramebuffer(f),f.name=0,eb[e]=null)}},glDeleteProgram:a=>{if(a){var b=H[a];b?(F.deleteProgram(b),b.name=0,H[a]=null):O||=1281}},glDeleteQueriesEXT:(a,b)=>{for(var d=0;d<a;d++){var e=t()[b+4*d>>2],f=M[e];f&&(F.o.deleteQueryEXT(f),M[e]=null)}},glDeleteRenderbuffers:(a,b)=>{for(var d=0;d<a;d++){var e=t()[b+4*d>>2],f=I[e];f&&(F.deleteRenderbuffer(f),f.name=0,I[e]=null)}},glDeleteShader:a=>
{if(a){var b=K[a];b?(F.deleteShader(b),K[a]=null):O||=1281}},glDeleteSync:a=>{if(a){var b=gb[a];b?(F.deleteSync(b),b.name=0,gb[a]=null):O||=1281}},glDeleteTextures:(a,b)=>{for(var d=0;d<a;d++){var e=t()[b+4*d>>2],f=J[e];f&&(F.deleteTexture(f),f.name=0,J[e]=null)}},glDeleteVertexArrays:(a,b)=>{for(var d=0;d<a;d++){var e=t()[b+4*d>>2];F.deleteVertexArray(fb[e]);fb[e]=null}},glDepthFunc:a=>F.depthFunc(a),glDepthMask:a=>{F.depthMask(!!a)},glDepthRangef:(a,b)=>F.depthRange(a,b),glDetachShader:(a,b)=>{F.detachShader(H[a],
K[b])},glDisable:a=>F.disable(a),glDisableVertexAttribArray:a=>{F.disableVertexAttribArray(a)},glDrawArrays:(a,b,d)=>{F.drawArrays(a,b,d)},glDrawElements:(a,b,d,e)=>{F.drawElements(a,b,d,e)},glEnable:a=>F.enable(a),glEnableVertexAttribArray:a=>{F.enableVertexAttribArray(a)},glEndQueryEXT:a=>{F.o.endQueryEXT(a)},glFenceSync:(a,b)=>(a=F.fenceSync(a,b))?(b=N(gb),a.name=b,gb[b]=a,b):0,glFinish:()=>F.finish(),glFlush:()=>F.flush(),glFramebufferRenderbuffer:(a,b,d,e)=>{F.framebufferRenderbuffer(a,b,d,I[e])},
glFramebufferTexture2D:(a,b,d,e,f)=>{F.framebufferTexture2D(a,b,d,J[e],f)},glFrontFace:a=>F.frontFace(a),glGenBuffers:(a,b)=>{lb(a,b,"createBuffer",G)},glGenFramebuffers:(a,b)=>{lb(a,b,"createFramebuffer",eb)},glGenQueriesEXT:(a,b)=>{for(var d=0;d<a;d++){var e=F.o.createQueryEXT();if(!e){for(O||=1282;d<a;)t()[b+4*d++>>2]=0;break}var f=N(M);e.name=f;M[f]=e;t()[b+4*d>>2]=f}},glGenRenderbuffers:(a,b)=>{lb(a,b,"createRenderbuffer",I)},glGenTextures:(a,b)=>{lb(a,b,"createTexture",J)},glGenVertexArrays:(a,
b)=>{lb(a,b,"createVertexArray",fb)},glGenerateMipmap:a=>F.generateMipmap(a),glGetActiveUniform:(a,b,d,e,f,h,l)=>{a=H[a];if(b=F.getActiveUniform(a,b))d=l&&E(b.name,l,d),e&&(t()[e>>2]=d),f&&(t()[f>>2]=b.size),h&&(t()[h>>2]=b.type)},glGetActiveUniformBlockName:(a,b,d,e,f)=>{a=H[a];if(a=F.getActiveUniformBlockName(a,b))f&&0<d?(d=E(a,f,d),e&&(t()[e>>2]=d)):e&&(t()[e>>2]=0)},glGetActiveUniformBlockiv:(a,b,d,e)=>{if(e)if(a=H[a],35393==d)d=F.getActiveUniformBlockName(a,b),t()[e>>2]=d.length+1;else{if(a=
F.getActiveUniformBlockParameter(a,b,d),null!==a)if(35395==d)for(d=0;d<a.length;d++)t()[e+4*d>>2]=a[d];else t()[e>>2]=a}else O||=1281},glGetBooleanv:(a,b)=>vb(a,b,4),glGetError:()=>{var a=F.getError()||O;O=0;return a},glGetFloatv:(a,b)=>vb(a,b,2),glGetFramebufferAttachmentParameteriv:(a,b,d,e)=>{a=F.getFramebufferAttachmentParameter(a,b,d);if(a instanceof WebGLRenderbuffer||a instanceof WebGLTexture)a=a.name|0;t()[e>>2]=a},glGetIntegerv:wb,glGetProgramInfoLog:(a,b,d,e)=>{a=F.getProgramInfoLog(H[a]);
null===a&&(a="(unknown error)");b=0<b&&e?E(a,e,b):0;d&&(t()[d>>2]=b)},glGetProgramiv:(a,b,d)=>{if(d)if(a>=db)O||=1281;else if(a=H[a],35716==b)a=F.getProgramInfoLog(a),null===a&&(a="(unknown error)"),t()[d>>2]=a.length+1;else if(35719==b){if(!a.C){var e=F.getProgramParameter(a,35718);for(b=0;b<e;++b)a.C=Math.max(a.C,F.getActiveUniform(a,b).name.length+1)}t()[d>>2]=a.C}else if(35722==b){if(!a.A)for(e=F.getProgramParameter(a,35721),b=0;b<e;++b)a.A=Math.max(a.A,F.getActiveAttrib(a,b).name.length+1);t()[d>>
2]=a.A}else if(35381==b){if(!a.B)for(e=F.getProgramParameter(a,35382),b=0;b<e;++b)a.B=Math.max(a.B,F.getActiveUniformBlockName(a,b).length+1);t()[d>>2]=a.B}else t()[d>>2]=F.getProgramParameter(a,b);else O||=1281},glGetQueryObjectui64vEXT:(a,b,d)=>{if(d){a=M[a];b=2>P.version?F.o.getQueryObjectEXT(a,b):F.getQueryParameter(a,b);var e;"boolean"==typeof b?e=b?1:0:e=b;tb(d,e)}else O||=1281},glGetQueryObjectuivEXT:(a,b,d)=>{if(d){a=F.o.getQueryObjectEXT(M[a],b);var e;"boolean"==typeof a?e=a?1:0:e=a;t()[d>>
2]=e}else O||=1281},glGetShaderInfoLog:(a,b,d,e)=>{a=F.getShaderInfoLog(K[a]);null===a&&(a="(unknown error)");b=0<b&&e?E(a,e,b):0;d&&(t()[d>>2]=b)},glGetShaderSource:(a,b,d,e)=>{if(a=F.getShaderSource(K[a]))b=0<b&&e?E(a,e,b):0,d&&(t()[d>>2]=b)},glGetShaderiv:(a,b,d)=>{d?35716==b?(a=F.getShaderInfoLog(K[a]),null===a&&(a="(unknown error)"),a=a?a.length+1:0,t()[d>>2]=a):35720==b?(a=(a=F.getShaderSource(K[a]))?a.length+1:0,t()[d>>2]=a):t()[d>>2]=F.getShaderParameter(K[a],b):O||=1281},glGetString:a=>{var b=
hb[a];if(!b){switch(a){case 7939:b=Hb(ub().join(" "));break;case 7936:case 7937:case 37445:case 37446:(b=F.getParameter(a))||(O||=1280);b=b?Hb(b):0;break;case 7938:b=F.getParameter(7938);var d=`OpenGL ES 2.0 (${b})`;2<=P.version&&(d=`OpenGL ES 3.0 (${b})`);b=Hb(d);break;case 35724:b=F.getParameter(35724);d=b.match(/^WebGL GLSL ES ([0-9]\.[0-9][0-9]?)(?:$| .*)/);null!==d&&(3==d[1].length&&(d[1]+="0"),b=`OpenGL ES GLSL ES ${d[1]} (${b})`);b=Hb(b);break;default:O||=1280}hb[a]=b}return b},glGetStringi:(a,
b)=>{if(2>P.version)return O||=1282,0;var d=ib[a];if(d)return 0>b||b>=d.length?(O||=1281,0):d[b];switch(a){case 7939:return d=ub().map(Hb),d=ib[a]=d,0>b||b>=d.length?(O||=1281,0):d[b];default:return O||=1280,0}},glGetUniformBlockIndex:(a,b)=>F.getUniformBlockIndex(H[a],C(b)),glGetUniformLocation:(a,b)=>{b=C(b);if(a=H[a]){var d=a,e=d.u,f=d.L,h;if(!e){d.u=e={};d.K={};var l=F.getProgramParameter(d,35718);for(h=0;h<l;++h){var m=F.getActiveUniform(d,h);var n=m.name;m=m.size;var r=Ib(n);r=0<r?n.slice(0,
r):n;var Q=d.G;d.G+=m;f[r]=[m,Q];for(n=0;n<m;++n)e[Q]=n,d.K[Q++]=r}}d=a.u;e=0;f=b;h=Ib(b);0<h&&(e=parseInt(b.slice(h+1))>>>0,f=b.slice(0,h));if((f=a.L[f])&&e<f[0]&&(e+=f[1],d[e]=d[e]||F.getUniformLocation(a,b)))return e}else O||=1281;return-1},glIsBuffer:a=>(a=G[a])?F.isBuffer(a):0,glIsFramebuffer:a=>(a=eb[a])?F.isFramebuffer(a):0,glIsProgram:a=>(a=H[a])?F.isProgram(a):0,glIsRenderbuffer:a=>(a=I[a])?F.isRenderbuffer(a):0,glIsShader:a=>(a=K[a])?F.isShader(a):0,glIsTexture:a=>(a=J[a])?F.isTexture(a):
0,glLinkProgram:a=>{a=H[a];F.linkProgram(a);a.u=0;a.L={}},glPixelStorei:(a,b)=>{3317==a?jb=b:3314==a&&(kb=b);F.pixelStorei(a,b)},glReadPixels:zb,glRenderbufferStorage:(a,b,d,e)=>F.renderbufferStorage(a,b,d,e),glRenderbufferStorageMultisample:(a,b,d,e,f)=>F.renderbufferStorageMultisample(a,b,d,e,f),glScissor:(a,b,d,e)=>F.scissor(a,b,d,e),glShaderBinary:()=>{O||=1280},glShaderSource:(a,b,d,e)=>{for(var f="",h=0;h<b;++h){var l=e?u()[e+4*h>>2]:void 0;f+=C(u()[d+4*h>>2],l)}F.shaderSource(K[a],f)},glStencilFuncSeparate:(a,
b,d,e)=>F.stencilFuncSeparate(a,b,d,e),glStencilMaskSeparate:(a,b)=>F.stencilMaskSeparate(a,b),glStencilOpSeparate:(a,b,d,e)=>F.stencilOpSeparate(a,b,d,e),glTexImage2D:(a,b,d,e,f,h,l,m,n)=>{if(2<=P.version){if(F.v){F.texImage2D(a,b,d,e,f,h,l,m,n);return}if(n){var r=xb(m);n>>>=31-Math.clz32(r.BYTES_PER_ELEMENT);F.texImage2D(a,b,d,e,f,h,l,m,r,n);return}}r=n?yb(m,l,e,f,n):null;F.texImage2D(a,b,d,e,f,h,l,m,r)},glTexParameterfv:(a,b,d)=>{d=v()[d>>2];F.texParameterf(a,b,d)},glTexParameteri:(a,b,d)=>F.texParameteri(a,
b,d),glTexSubImage2D:(a,b,d,e,f,h,l,m,n)=>{if(2<=P.version){if(F.v){F.texSubImage2D(a,b,d,e,f,h,l,m,n);return}if(n){var r=xb(m);F.texSubImage2D(a,b,d,e,f,h,l,m,r,n>>>31-Math.clz32(r.BYTES_PER_ELEMENT));return}}n=n?yb(m,l,f,h,n):null;F.texSubImage2D(a,b,d,e,f,h,l,m,n)},glUniform1fv:(a,b,d)=>{if(2<=P.version)b&&F.uniform1fv(S(a),v(),d>>2,b);else{if(288>=b)for(var e=T[b],f=0;f<b;++f)e[f]=v()[d+4*f>>2];else e=v().subarray(d>>2,d+4*b>>2);F.uniform1fv(S(a),e)}},glUniform1i:(a,b)=>{F.uniform1i(S(a),b)},
glUniform2fv:(a,b,d)=>{if(2<=P.version)b&&F.uniform2fv(S(a),v(),d>>2,2*b);else{if(144>=b){b*=2;for(var e=T[b],f=0;f<b;f+=2)e[f]=v()[d+4*f>>2],e[f+1]=v()[d+(4*f+4)>>2]}else e=v().subarray(d>>2,d+8*b>>2);F.uniform2fv(S(a),e)}},glUniform3fv:(a,b,d)=>{if(2<=P.version)b&&F.uniform3fv(S(a),v(),d>>2,3*b);else{if(96>=b){b*=3;for(var e=T[b],f=0;f<b;f+=3)e[f]=v()[d+4*f>>2],e[f+1]=v()[d+(4*f+4)>>2],e[f+2]=v()[d+(4*f+8)>>2]}else e=v().subarray(d>>2,d+12*b>>2);F.uniform3fv(S(a),e)}},glUniform4fv:(a,b,d)=>{if(2<=
P.version)b&&F.uniform4fv(S(a),v(),d>>2,4*b);else{if(72>=b){var e=T[4*b],f=v();d>>=2;b*=4;for(var h=0;h<b;h+=4){var l=d+h;e[h]=f[l];e[h+1]=f[l+1];e[h+2]=f[l+2];e[h+3]=f[l+3]}}else e=v().subarray(d>>2,d+16*b>>2);F.uniform4fv(S(a),e)}},glUniformBlockBinding:(a,b,d)=>{a=H[a];F.uniformBlockBinding(a,b,d)},glUniformMatrix4fv:(a,b,d,e)=>{if(2<=P.version)b&&F.uniformMatrix4fv(S(a),!!d,v(),e>>2,16*b);else{if(18>=b){var f=T[16*b],h=v();e>>=2;b*=16;for(var l=0;l<b;l+=16){var m=e+l;f[l]=h[m];f[l+1]=h[m+1];f[l+
2]=h[m+2];f[l+3]=h[m+3];f[l+4]=h[m+4];f[l+5]=h[m+5];f[l+6]=h[m+6];f[l+7]=h[m+7];f[l+8]=h[m+8];f[l+9]=h[m+9];f[l+10]=h[m+10];f[l+11]=h[m+11];f[l+12]=h[m+12];f[l+13]=h[m+13];f[l+14]=h[m+14];f[l+15]=h[m+15]}}else f=v().subarray(e>>2,e+64*b>>2);F.uniformMatrix4fv(S(a),!!d,f)}},glUseProgram:a=>{a=H[a];F.useProgram(a);F.N=a},glVertexAttribPointer:(a,b,d,e,f,h)=>{F.vertexAttribPointer(a,b,d,!!e,f,h)},glViewport:(a,b,d,e)=>F.viewport(a,b,d,e),glWaitSync:(a,b,d,e)=>{F.waitSync(gb[a],b,(d>>>0)+4294967296*e)},
invoke_ii:Ac,invoke_iii:Bc,invoke_iiii:Cc,invoke_iiiii:Dc,invoke_iiiiiii:Ec,invoke_vi:Fc,invoke_vii:Gc,invoke_viii:Hc,invoke_viiiiiii:Ic,memory:g,proc_exit:Pa,skwasm_captureImageBitmap:Jb,skwasm_connectThread:Mb,skwasm_createGlTextureFromTextureSource:Nb,skwasm_destroyContext:Ob,skwasm_dispatchDisposeSurface:Pb,skwasm_dispatchRasterizeImage:Qb,skwasm_dispatchRenderPictures:Rb,skwasm_dispatchResizeSurface:Sb,skwasm_dispatchTransferCanvas:Tb,skwasm_dispatchTriggerContextLoss:Ub,skwasm_disposeAssociatedObjectOnThread:Vb,
skwasm_getAssociatedObject:Wb,skwasm_getGlContextForCanvas:Xb,skwasm_isSingleThreaded:Yb,skwasm_postRasterizeResult:Zb,skwasm_reportContextLossTriggered:$b,skwasm_reportContextLost:ac,skwasm_reportInitialized:bc,skwasm_reportResizeComplete:cc,skwasm_resizeCanvas:dc,skwasm_resolveAndPostImages:ec,skwasm_setAssociatedObjectOnThread:fc,skwasm_triggerContextLossOnCanvas:gc},W=function(){function a(d,e){W=d.exports;w.wasmExports=W;B=W.__indirect_function_table;wa.unshift(W.__wasm_call_ctors);qa=e;z--;
0==z&&(null!==Fa&&(clearInterval(Fa),Fa=null),A&&(d=A,A=null,d()));return W}var b={env:Jc,wasi_snapshot_preview1:Jc};z++;if(w.instantiateWasm)try{return w.instantiateWasm(b,a)}catch(d){y(`Module.instantiateWasm callback failed with error: ${d}`),fa(d)}Ia??=Ha("wimp.wasm")?"wimp.wasm":ma("wimp.wasm");La(b,function(d){a(d.instance,d.module)}).catch(fa);return{}}();w._canvas_saveLayer=(a,b,d,e)=>(w._canvas_saveLayer=W.canvas_saveLayer)(a,b,d,e);w._canvas_save=a=>(w._canvas_save=W.canvas_save)(a);
w._canvas_restore=a=>(w._canvas_restore=W.canvas_restore)(a);w._canvas_restoreToCount=(a,b)=>(w._canvas_restoreToCount=W.canvas_restoreToCount)(a,b);w._canvas_getSaveCount=a=>(w._canvas_getSaveCount=W.canvas_getSaveCount)(a);w._canvas_translate=(a,b,d)=>(w._canvas_translate=W.canvas_translate)(a,b,d);w._canvas_scale=(a,b,d)=>(w._canvas_scale=W.canvas_scale)(a,b,d);w._canvas_rotate=(a,b)=>(w._canvas_rotate=W.canvas_rotate)(a,b);w._canvas_skew=(a,b,d)=>(w._canvas_skew=W.canvas_skew)(a,b,d);
w._canvas_transform=(a,b)=>(w._canvas_transform=W.canvas_transform)(a,b);w._canvas_clear=(a,b)=>(w._canvas_clear=W.canvas_clear)(a,b);w._canvas_clipRect=(a,b,d,e)=>(w._canvas_clipRect=W.canvas_clipRect)(a,b,d,e);w._canvas_clipRRect=(a,b,d)=>(w._canvas_clipRRect=W.canvas_clipRRect)(a,b,d);w._canvas_clipPath=(a,b,d)=>(w._canvas_clipPath=W.canvas_clipPath)(a,b,d);w._canvas_drawColor=(a,b,d)=>(w._canvas_drawColor=W.canvas_drawColor)(a,b,d);
w._canvas_drawLine=(a,b,d,e,f,h)=>(w._canvas_drawLine=W.canvas_drawLine)(a,b,d,e,f,h);w._canvas_drawPaint=(a,b)=>(w._canvas_drawPaint=W.canvas_drawPaint)(a,b);w._canvas_drawRect=(a,b,d)=>(w._canvas_drawRect=W.canvas_drawRect)(a,b,d);w._canvas_drawRRect=(a,b,d)=>(w._canvas_drawRRect=W.canvas_drawRRect)(a,b,d);w._canvas_drawDRRect=(a,b,d,e)=>(w._canvas_drawDRRect=W.canvas_drawDRRect)(a,b,d,e);w._canvas_drawOval=(a,b,d)=>(w._canvas_drawOval=W.canvas_drawOval)(a,b,d);
w._canvas_drawCircle=(a,b,d,e,f)=>(w._canvas_drawCircle=W.canvas_drawCircle)(a,b,d,e,f);w._canvas_drawArc=(a,b,d,e,f,h)=>(w._canvas_drawArc=W.canvas_drawArc)(a,b,d,e,f,h);w._canvas_drawPath=(a,b,d)=>(w._canvas_drawPath=W.canvas_drawPath)(a,b,d);w._canvas_drawShadow=(a,b,d,e,f,h)=>(w._canvas_drawShadow=W.canvas_drawShadow)(a,b,d,e,f,h);w._canvas_drawParagraph=(a,b,d,e)=>(w._canvas_drawParagraph=W.canvas_drawParagraph)(a,b,d,e);
w._canvas_drawPicture=(a,b)=>(w._canvas_drawPicture=W.canvas_drawPicture)(a,b);w._canvas_drawImage=(a,b,d,e,f,h)=>(w._canvas_drawImage=W.canvas_drawImage)(a,b,d,e,f,h);w._canvas_drawImageRect=(a,b,d,e,f,h)=>(w._canvas_drawImageRect=W.canvas_drawImageRect)(a,b,d,e,f,h);w._canvas_drawImageNine=(a,b,d,e,f,h)=>(w._canvas_drawImageNine=W.canvas_drawImageNine)(a,b,d,e,f,h);w._canvas_drawVertices=(a,b,d,e)=>(w._canvas_drawVertices=W.canvas_drawVertices)(a,b,d,e);
w._canvas_drawPoints=(a,b,d,e,f)=>(w._canvas_drawPoints=W.canvas_drawPoints)(a,b,d,e,f);w._canvas_drawAtlas=(a,b,d,e,f,h,l,m,n)=>(w._canvas_drawAtlas=W.canvas_drawAtlas)(a,b,d,e,f,h,l,m,n);w._canvas_getTransform=(a,b)=>(w._canvas_getTransform=W.canvas_getTransform)(a,b);w._canvas_getLocalClipBounds=(a,b)=>(w._canvas_getLocalClipBounds=W.canvas_getLocalClipBounds)(a,b);w._canvas_getDeviceClipBounds=(a,b)=>(w._canvas_getDeviceClipBounds=W.canvas_getDeviceClipBounds)(a,b);
w._canvas_quickReject=(a,b)=>(w._canvas_quickReject=W.canvas_quickReject)(a,b);w._contourMeasureIter_create=(a,b,d)=>(w._contourMeasureIter_create=W.contourMeasureIter_create)(a,b,d);w._contourMeasureIter_next=a=>(w._contourMeasureIter_next=W.contourMeasureIter_next)(a);w._contourMeasureIter_dispose=a=>(w._contourMeasureIter_dispose=W.contourMeasureIter_dispose)(a);w._contourMeasure_dispose=a=>(w._contourMeasure_dispose=W.contourMeasure_dispose)(a);
w._contourMeasure_length=a=>(w._contourMeasure_length=W.contourMeasure_length)(a);w._contourMeasure_isClosed=a=>(w._contourMeasure_isClosed=W.contourMeasure_isClosed)(a);w._contourMeasure_getPosTan=(a,b,d,e)=>(w._contourMeasure_getPosTan=W.contourMeasure_getPosTan)(a,b,d,e);w._contourMeasure_getSegment=(a,b,d,e)=>(w._contourMeasure_getSegment=W.contourMeasure_getSegment)(a,b,d,e);w._skData_create=a=>(w._skData_create=W.skData_create)(a);w._skData_getPointer=a=>(w._skData_getPointer=W.skData_getPointer)(a);
w._skData_getConstPointer=a=>(w._skData_getConstPointer=W.skData_getConstPointer)(a);w._skData_getSize=a=>(w._skData_getSize=W.skData_getSize)(a);w._skData_dispose=a=>(w._skData_dispose=W.skData_dispose)(a);w._imageFilter_createBlur=(a,b,d)=>(w._imageFilter_createBlur=W.imageFilter_createBlur)(a,b,d);w._imageFilter_createDilate=(a,b)=>(w._imageFilter_createDilate=W.imageFilter_createDilate)(a,b);w._imageFilter_createErode=(a,b)=>(w._imageFilter_createErode=W.imageFilter_createErode)(a,b);
w._imageFilter_createMatrix=(a,b)=>(w._imageFilter_createMatrix=W.imageFilter_createMatrix)(a,b);w._imageFilter_createFromColorFilter=a=>(w._imageFilter_createFromColorFilter=W.imageFilter_createFromColorFilter)(a);w._imageFilter_compose=(a,b)=>(w._imageFilter_compose=W.imageFilter_compose)(a,b);w._imageFilter_dispose=a=>(w._imageFilter_dispose=W.imageFilter_dispose)(a);w._imageFilter_getFilterBounds=(a,b)=>(w._imageFilter_getFilterBounds=W.imageFilter_getFilterBounds)(a,b);
w._colorFilter_createMode=(a,b)=>(w._colorFilter_createMode=W.colorFilter_createMode)(a,b);w._colorFilter_createMatrix=a=>(w._colorFilter_createMatrix=W.colorFilter_createMatrix)(a);w._colorFilter_createSRGBToLinearGamma=()=>(w._colorFilter_createSRGBToLinearGamma=W.colorFilter_createSRGBToLinearGamma)();w._colorFilter_createLinearToSRGBGamma=()=>(w._colorFilter_createLinearToSRGBGamma=W.colorFilter_createLinearToSRGBGamma)();w._colorFilter_dispose=a=>(w._colorFilter_dispose=W.colorFilter_dispose)(a);
w._maskFilter_createBlur=(a,b)=>(w._maskFilter_createBlur=W.maskFilter_createBlur)(a,b);w._maskFilter_dispose=a=>(w._maskFilter_dispose=W.maskFilter_dispose)(a);w._fontCollection_create=()=>(w._fontCollection_create=W.fontCollection_create)();w._fontCollection_dispose=a=>(w._fontCollection_dispose=W.fontCollection_dispose)(a);w._typeface_create=a=>(w._typeface_create=W.typeface_create)(a);w._typeface_dispose=a=>(w._typeface_dispose=W.typeface_dispose)(a);
w._typefaces_filterCoveredCodePoints=(a,b,d,e)=>(w._typefaces_filterCoveredCodePoints=W.typefaces_filterCoveredCodePoints)(a,b,d,e);w._fontCollection_registerTypeface=(a,b,d)=>(w._fontCollection_registerTypeface=W.fontCollection_registerTypeface)(a,b,d);w._fontCollection_clearCaches=a=>(w._fontCollection_clearCaches=W.fontCollection_clearCaches)(a);w._image_createFromPicture=(a,b,d)=>(w._image_createFromPicture=W.image_createFromPicture)(a,b,d);
w._image_createFromPixels=(a,b,d,e,f)=>(w._image_createFromPixels=W.image_createFromPixels)(a,b,d,e,f);w._image_createFromTextureSource=(a,b,d,e)=>(w._image_createFromTextureSource=W.image_createFromTextureSource)(a,b,d,e);w._image_ref=a=>(w._image_ref=W.image_ref)(a);w._image_dispose=a=>(w._image_dispose=W.image_dispose)(a);w._image_getWidth=a=>(w._image_getWidth=W.image_getWidth)(a);w._image_getHeight=a=>(w._image_getHeight=W.image_getHeight)(a);
w._skwasm_getLiveObjectCounts=a=>(w._skwasm_getLiveObjectCounts=W.skwasm_getLiveObjectCounts)(a);w._paint_create=(a,b,d,e,f,h,l,m,n)=>(w._paint_create=W.paint_create)(a,b,d,e,f,h,l,m,n);w._paint_dispose=a=>(w._paint_dispose=W.paint_dispose)(a);w._paint_setShader=(a,b)=>(w._paint_setShader=W.paint_setShader)(a,b);w._paint_setImageFilter=(a,b)=>(w._paint_setImageFilter=W.paint_setImageFilter)(a,b);w._paint_setColorFilter=(a,b)=>(w._paint_setColorFilter=W.paint_setColorFilter)(a,b);
w._paint_setMaskFilter=(a,b)=>(w._paint_setMaskFilter=W.paint_setMaskFilter)(a,b);w._path_create=()=>(w._path_create=W.path_create)();w._path_dispose=a=>(w._path_dispose=W.path_dispose)(a);w._path_copy=a=>(w._path_copy=W.path_copy)(a);w._path_setFillType=(a,b)=>(w._path_setFillType=W.path_setFillType)(a,b);w._path_getFillType=a=>(w._path_getFillType=W.path_getFillType)(a);w._path_moveTo=(a,b,d)=>(w._path_moveTo=W.path_moveTo)(a,b,d);
w._path_relativeMoveTo=(a,b,d)=>(w._path_relativeMoveTo=W.path_relativeMoveTo)(a,b,d);w._path_lineTo=(a,b,d)=>(w._path_lineTo=W.path_lineTo)(a,b,d);w._path_relativeLineTo=(a,b,d)=>(w._path_relativeLineTo=W.path_relativeLineTo)(a,b,d);w._path_quadraticBezierTo=(a,b,d,e,f)=>(w._path_quadraticBezierTo=W.path_quadraticBezierTo)(a,b,d,e,f);w._path_relativeQuadraticBezierTo=(a,b,d,e,f)=>(w._path_relativeQuadraticBezierTo=W.path_relativeQuadraticBezierTo)(a,b,d,e,f);
w._path_cubicTo=(a,b,d,e,f,h,l)=>(w._path_cubicTo=W.path_cubicTo)(a,b,d,e,f,h,l);w._path_relativeCubicTo=(a,b,d,e,f,h,l)=>(w._path_relativeCubicTo=W.path_relativeCubicTo)(a,b,d,e,f,h,l);w._path_conicTo=(a,b,d,e,f,h)=>(w._path_conicTo=W.path_conicTo)(a,b,d,e,f,h);w._path_relativeConicTo=(a,b,d,e,f,h)=>(w._path_relativeConicTo=W.path_relativeConicTo)(a,b,d,e,f,h);w._path_arcToOval=(a,b,d,e,f)=>(w._path_arcToOval=W.path_arcToOval)(a,b,d,e,f);
w._path_arcToRotated=(a,b,d,e,f,h,l,m)=>(w._path_arcToRotated=W.path_arcToRotated)(a,b,d,e,f,h,l,m);w._path_relativeArcToRotated=(a,b,d,e,f,h,l,m)=>(w._path_relativeArcToRotated=W.path_relativeArcToRotated)(a,b,d,e,f,h,l,m);w._path_addRect=(a,b)=>(w._path_addRect=W.path_addRect)(a,b);w._path_addOval=(a,b)=>(w._path_addOval=W.path_addOval)(a,b);w._path_addArc=(a,b,d,e)=>(w._path_addArc=W.path_addArc)(a,b,d,e);w._path_addPolygon=(a,b,d,e)=>(w._path_addPolygon=W.path_addPolygon)(a,b,d,e);
w._path_addRRect=(a,b)=>(w._path_addRRect=W.path_addRRect)(a,b);w._path_addPath=(a,b,d,e)=>(w._path_addPath=W.path_addPath)(a,b,d,e);w._path_close=a=>(w._path_close=W.path_close)(a);w._path_reset=a=>(w._path_reset=W.path_reset)(a);w._path_contains=(a,b,d)=>(w._path_contains=W.path_contains)(a,b,d);w._path_transform=(a,b)=>(w._path_transform=W.path_transform)(a,b);w._path_getBounds=(a,b)=>(w._path_getBounds=W.path_getBounds)(a,b);w._path_combine=(a,b,d)=>(w._path_combine=W.path_combine)(a,b,d);
w._path_getSvgString=a=>(w._path_getSvgString=W.path_getSvgString)(a);w._pictureRecorder_create=()=>(w._pictureRecorder_create=W.pictureRecorder_create)();w._pictureRecorder_dispose=a=>(w._pictureRecorder_dispose=W.pictureRecorder_dispose)(a);w._pictureRecorder_beginRecording=(a,b)=>(w._pictureRecorder_beginRecording=W.pictureRecorder_beginRecording)(a,b);w._pictureRecorder_endRecording=a=>(w._pictureRecorder_endRecording=W.pictureRecorder_endRecording)(a);
w._picture_getCullRect=(a,b)=>(w._picture_getCullRect=W.picture_getCullRect)(a,b);w._picture_ref=a=>(w._picture_ref=W.picture_ref)(a);w._picture_dispose=a=>(w._picture_dispose=W.picture_dispose)(a);w._picture_approximateBytesUsed=a=>(w._picture_approximateBytesUsed=W.picture_approximateBytesUsed)(a);w._shader_createLinearGradient=(a,b,d,e,f,h)=>(w._shader_createLinearGradient=W.shader_createLinearGradient)(a,b,d,e,f,h);
w._shader_createRadialGradient=(a,b,d,e,f,h,l,m)=>(w._shader_createRadialGradient=W.shader_createRadialGradient)(a,b,d,e,f,h,l,m);w._shader_createConicalGradient=(a,b,d,e,f,h,l,m)=>(w._shader_createConicalGradient=W.shader_createConicalGradient)(a,b,d,e,f,h,l,m);w._shader_createSweepGradient=(a,b,d,e,f,h,l,m,n)=>(w._shader_createSweepGradient=W.shader_createSweepGradient)(a,b,d,e,f,h,l,m,n);w._shader_dispose=a=>(w._shader_dispose=W.shader_dispose)(a);
w._runtimeEffect_create=a=>(w._runtimeEffect_create=W.runtimeEffect_create)(a);w._runtimeEffect_dispose=a=>(w._runtimeEffect_dispose=W.runtimeEffect_dispose)(a);w._runtimeEffect_getUniformSize=a=>(w._runtimeEffect_getUniformSize=W.runtimeEffect_getUniformSize)(a);w._shader_createRuntimeEffectShader=(a,b,d,e)=>(w._shader_createRuntimeEffectShader=W.shader_createRuntimeEffectShader)(a,b,d,e);w._shader_createFromImage=(a,b,d,e,f)=>(w._shader_createFromImage=W.shader_createFromImage)(a,b,d,e,f);
w._uniformData_create=a=>(w._uniformData_create=W.uniformData_create)(a);w._uniformData_dispose=a=>(w._uniformData_dispose=W.uniformData_dispose)(a);w._uniformData_getPointer=a=>(w._uniformData_getPointer=W.uniformData_getPointer)(a);w._skString_allocate=a=>(w._skString_allocate=W.skString_allocate)(a);w._skString_getData=a=>(w._skString_getData=W.skString_getData)(a);w._skString_getLength=a=>(w._skString_getLength=W.skString_getLength)(a);w._skString_free=a=>(w._skString_free=W.skString_free)(a);
w._skString16_allocate=a=>(w._skString16_allocate=W.skString16_allocate)(a);w._skString16_getData=a=>(w._skString16_getData=W.skString16_getData)(a);w._skString16_free=a=>(w._skString16_free=W.skString16_free)(a);w._surface_create=()=>(w._surface_create=W.surface_create)();w._surface_setCanvas=(a,b)=>(w._surface_setCanvas=W.surface_setCanvas)(a,b);
var mc=w._surface_receiveCanvasOnWorker=(a,b,d)=>(mc=w._surface_receiveCanvasOnWorker=W.surface_receiveCanvasOnWorker)(a,b,d),nc=w._surface_onInitialized=(a,b)=>(nc=w._surface_onInitialized=W.surface_onInitialized)(a,b);w._surface_setSize=(a,b,d)=>(w._surface_setSize=W.surface_setSize)(a,b,d);
var oc=w._surface_resizeOnWorker=(a,b,d,e)=>(oc=w._surface_resizeOnWorker=W.surface_resizeOnWorker)(a,b,d,e),pc=w._surface_onResizeComplete=(a,b)=>(pc=w._surface_onResizeComplete=W.surface_onResizeComplete)(a,b);w._surface_getThreadId=a=>(w._surface_getThreadId=W.surface_getThreadId)(a);w._surface_getGlContext=a=>(w._surface_getGlContext=W.surface_getGlContext)(a);w._surface_triggerContextLoss=a=>(w._surface_triggerContextLoss=W.surface_triggerContextLoss)(a);
var qc=w._surface_triggerContextLossOnWorker=(a,b)=>(qc=w._surface_triggerContextLossOnWorker=W.surface_triggerContextLossOnWorker)(a,b),rc=w._surface_onContextLossTriggered=(a,b)=>(rc=w._surface_onContextLossTriggered=W.surface_onContextLossTriggered)(a,b),sc=w._surface_reportContextLost=(a,b)=>(sc=w._surface_reportContextLost=W.surface_reportContextLost)(a,b);w._surface_setCallbackHandler=(a,b)=>(w._surface_setCallbackHandler=W.surface_setCallbackHandler)(a,b);
w._surface_destroy=a=>(w._surface_destroy=W.surface_destroy)(a);var vc=w._surface_dispose=a=>(vc=w._surface_dispose=W.surface_dispose)(a);w._surface_setResourceCacheLimitBytes=(a,b)=>(w._surface_setResourceCacheLimitBytes=W.surface_setResourceCacheLimitBytes)(a,b);w._surface_renderPictures=(a,b,d)=>(w._surface_renderPictures=W.surface_renderPictures)(a,b,d);var tc=w._surface_renderPicturesOnWorker=(a,b,d,e,f)=>(tc=w._surface_renderPicturesOnWorker=W.surface_renderPicturesOnWorker)(a,b,d,e,f);
w._surface_rasterizeImage=(a,b,d)=>(w._surface_rasterizeImage=W.surface_rasterizeImage)(a,b,d);
var wc=w._surface_rasterizeImageOnWorker=(a,b,d,e)=>(wc=w._surface_rasterizeImageOnWorker=W.surface_rasterizeImageOnWorker)(a,b,d,e),uc=w._surface_onRenderComplete=(a,b,d)=>(uc=w._surface_onRenderComplete=W.surface_onRenderComplete)(a,b,d),xc=w._surface_onRasterizeComplete=(a,b,d)=>(xc=w._surface_onRasterizeComplete=W.surface_onRasterizeComplete)(a,b,d),yc=w._surface_onContextLost=a=>(yc=w._surface_onContextLost=W.surface_onContextLost)(a);
w._skwasm_isMultiThreaded=()=>(w._skwasm_isMultiThreaded=W.skwasm_isMultiThreaded)();w._lineMetrics_create=(a,b,d,e,f,h,l,m,n)=>(w._lineMetrics_create=W.lineMetrics_create)(a,b,d,e,f,h,l,m,n);w._lineMetrics_dispose=a=>(w._lineMetrics_dispose=W.lineMetrics_dispose)(a);w._lineMetrics_getHardBreak=a=>(w._lineMetrics_getHardBreak=W.lineMetrics_getHardBreak)(a);w._lineMetrics_getAscent=a=>(w._lineMetrics_getAscent=W.lineMetrics_getAscent)(a);w._lineMetrics_getDescent=a=>(w._lineMetrics_getDescent=W.lineMetrics_getDescent)(a);
w._lineMetrics_getUnscaledAscent=a=>(w._lineMetrics_getUnscaledAscent=W.lineMetrics_getUnscaledAscent)(a);w._lineMetrics_getHeight=a=>(w._lineMetrics_getHeight=W.lineMetrics_getHeight)(a);w._lineMetrics_getWidth=a=>(w._lineMetrics_getWidth=W.lineMetrics_getWidth)(a);w._lineMetrics_getLeft=a=>(w._lineMetrics_getLeft=W.lineMetrics_getLeft)(a);w._lineMetrics_getBaseline=a=>(w._lineMetrics_getBaseline=W.lineMetrics_getBaseline)(a);w._lineMetrics_getLineNumber=a=>(w._lineMetrics_getLineNumber=W.lineMetrics_getLineNumber)(a);
w._lineMetrics_getStartIndex=a=>(w._lineMetrics_getStartIndex=W.lineMetrics_getStartIndex)(a);w._lineMetrics_getEndIndex=a=>(w._lineMetrics_getEndIndex=W.lineMetrics_getEndIndex)(a);w._paragraph_dispose=a=>(w._paragraph_dispose=W.paragraph_dispose)(a);w._paragraph_getWidth=a=>(w._paragraph_getWidth=W.paragraph_getWidth)(a);w._paragraph_getHeight=a=>(w._paragraph_getHeight=W.paragraph_getHeight)(a);w._paragraph_getLongestLine=a=>(w._paragraph_getLongestLine=W.paragraph_getLongestLine)(a);
w._paragraph_getMinIntrinsicWidth=a=>(w._paragraph_getMinIntrinsicWidth=W.paragraph_getMinIntrinsicWidth)(a);w._paragraph_getMaxIntrinsicWidth=a=>(w._paragraph_getMaxIntrinsicWidth=W.paragraph_getMaxIntrinsicWidth)(a);w._paragraph_getAlphabeticBaseline=a=>(w._paragraph_getAlphabeticBaseline=W.paragraph_getAlphabeticBaseline)(a);w._paragraph_getIdeographicBaseline=a=>(w._paragraph_getIdeographicBaseline=W.paragraph_getIdeographicBaseline)(a);
w._paragraph_getDidExceedMaxLines=a=>(w._paragraph_getDidExceedMaxLines=W.paragraph_getDidExceedMaxLines)(a);w._paragraph_layout=(a,b)=>(w._paragraph_layout=W.paragraph_layout)(a,b);w._paragraph_getPositionForOffset=(a,b,d,e)=>(w._paragraph_getPositionForOffset=W.paragraph_getPositionForOffset)(a,b,d,e);w._paragraph_getClosestGlyphInfoAtCoordinate=(a,b,d,e,f,h)=>(w._paragraph_getClosestGlyphInfoAtCoordinate=W.paragraph_getClosestGlyphInfoAtCoordinate)(a,b,d,e,f,h);
w._paragraph_getGlyphInfoAt=(a,b,d,e,f)=>(w._paragraph_getGlyphInfoAt=W.paragraph_getGlyphInfoAt)(a,b,d,e,f);w._paragraph_getWordBoundary=(a,b,d)=>(w._paragraph_getWordBoundary=W.paragraph_getWordBoundary)(a,b,d);w._paragraph_getLineCount=a=>(w._paragraph_getLineCount=W.paragraph_getLineCount)(a);w._paragraph_getLineNumberAt=(a,b)=>(w._paragraph_getLineNumberAt=W.paragraph_getLineNumberAt)(a,b);
w._paragraph_getLineMetricsAtIndex=(a,b)=>(w._paragraph_getLineMetricsAtIndex=W.paragraph_getLineMetricsAtIndex)(a,b);w._textBoxList_dispose=a=>(w._textBoxList_dispose=W.textBoxList_dispose)(a);w._textBoxList_getLength=a=>(w._textBoxList_getLength=W.textBoxList_getLength)(a);w._textBoxList_getBoxAtIndex=(a,b,d)=>(w._textBoxList_getBoxAtIndex=W.textBoxList_getBoxAtIndex)(a,b,d);w._paragraph_getBoxesForRange=(a,b,d,e,f)=>(w._paragraph_getBoxesForRange=W.paragraph_getBoxesForRange)(a,b,d,e,f);
w._paragraph_getBoxesForPlaceholders=a=>(w._paragraph_getBoxesForPlaceholders=W.paragraph_getBoxesForPlaceholders)(a);w._paragraph_getUnresolvedCodePoints=(a,b,d)=>(w._paragraph_getUnresolvedCodePoints=W.paragraph_getUnresolvedCodePoints)(a,b,d);w._paragraphBuilder_dispose=a=>(w._paragraphBuilder_dispose=W.paragraphBuilder_dispose)(a);w._paragraphBuilder_addPlaceholder=(a,b,d,e,f,h)=>(w._paragraphBuilder_addPlaceholder=W.paragraphBuilder_addPlaceholder)(a,b,d,e,f,h);
w._paragraphBuilder_addText=(a,b)=>(w._paragraphBuilder_addText=W.paragraphBuilder_addText)(a,b);w._paragraphBuilder_getUtf8Text=(a,b)=>(w._paragraphBuilder_getUtf8Text=W.paragraphBuilder_getUtf8Text)(a,b);w._paragraphBuilder_pushStyle=(a,b)=>(w._paragraphBuilder_pushStyle=W.paragraphBuilder_pushStyle)(a,b);w._paragraphBuilder_pop=a=>(w._paragraphBuilder_pop=W.paragraphBuilder_pop)(a);w._unicodePositionBuffer_create=a=>(w._unicodePositionBuffer_create=W.unicodePositionBuffer_create)(a);
w._unicodePositionBuffer_getDataPointer=a=>(w._unicodePositionBuffer_getDataPointer=W.unicodePositionBuffer_getDataPointer)(a);w._unicodePositionBuffer_free=a=>(w._unicodePositionBuffer_free=W.unicodePositionBuffer_free)(a);w._lineBreakBuffer_create=a=>(w._lineBreakBuffer_create=W.lineBreakBuffer_create)(a);w._lineBreakBuffer_getDataPointer=a=>(w._lineBreakBuffer_getDataPointer=W.lineBreakBuffer_getDataPointer)(a);w._lineBreakBuffer_free=a=>(w._lineBreakBuffer_free=W.lineBreakBuffer_free)(a);
w._paragraphStyle_create=()=>(w._paragraphStyle_create=W.paragraphStyle_create)();w._paragraphStyle_dispose=a=>(w._paragraphStyle_dispose=W.paragraphStyle_dispose)(a);w._paragraphStyle_setTextAlign=(a,b)=>(w._paragraphStyle_setTextAlign=W.paragraphStyle_setTextAlign)(a,b);w._paragraphStyle_setTextDirection=(a,b)=>(w._paragraphStyle_setTextDirection=W.paragraphStyle_setTextDirection)(a,b);w._paragraphStyle_setMaxLines=(a,b)=>(w._paragraphStyle_setMaxLines=W.paragraphStyle_setMaxLines)(a,b);
w._paragraphStyle_setHeight=(a,b)=>(w._paragraphStyle_setHeight=W.paragraphStyle_setHeight)(a,b);w._paragraphStyle_setTextHeightBehavior=(a,b,d)=>(w._paragraphStyle_setTextHeightBehavior=W.paragraphStyle_setTextHeightBehavior)(a,b,d);w._paragraphStyle_setEllipsis=(a,b)=>(w._paragraphStyle_setEllipsis=W.paragraphStyle_setEllipsis)(a,b);w._paragraphStyle_setStrutStyle=(a,b)=>(w._paragraphStyle_setStrutStyle=W.paragraphStyle_setStrutStyle)(a,b);
w._paragraphStyle_setTextStyle=(a,b)=>(w._paragraphStyle_setTextStyle=W.paragraphStyle_setTextStyle)(a,b);w._paragraphStyle_setApplyRoundingHack=(a,b)=>(w._paragraphStyle_setApplyRoundingHack=W.paragraphStyle_setApplyRoundingHack)(a,b);w._strutStyle_create=()=>(w._strutStyle_create=W.strutStyle_create)();w._strutStyle_dispose=a=>(w._strutStyle_dispose=W.strutStyle_dispose)(a);w._strutStyle_setFontFamilies=(a,b,d)=>(w._strutStyle_setFontFamilies=W.strutStyle_setFontFamilies)(a,b,d);
w._strutStyle_setFontSize=(a,b)=>(w._strutStyle_setFontSize=W.strutStyle_setFontSize)(a,b);w._strutStyle_setHeight=(a,b)=>(w._strutStyle_setHeight=W.strutStyle_setHeight)(a,b);w._strutStyle_setHalfLeading=(a,b)=>(w._strutStyle_setHalfLeading=W.strutStyle_setHalfLeading)(a,b);w._strutStyle_setLeading=(a,b)=>(w._strutStyle_setLeading=W.strutStyle_setLeading)(a,b);w._strutStyle_setFontStyle=(a,b,d)=>(w._strutStyle_setFontStyle=W.strutStyle_setFontStyle)(a,b,d);
w._strutStyle_setForceStrutHeight=(a,b)=>(w._strutStyle_setForceStrutHeight=W.strutStyle_setForceStrutHeight)(a,b);w._textStyle_create=()=>(w._textStyle_create=W.textStyle_create)();w._textStyle_copy=a=>(w._textStyle_copy=W.textStyle_copy)(a);w._textStyle_dispose=a=>(w._textStyle_dispose=W.textStyle_dispose)(a);w._textStyle_setColor=(a,b)=>(w._textStyle_setColor=W.textStyle_setColor)(a,b);w._textStyle_setDecoration=(a,b)=>(w._textStyle_setDecoration=W.textStyle_setDecoration)(a,b);
w._textStyle_setDecorationColor=(a,b)=>(w._textStyle_setDecorationColor=W.textStyle_setDecorationColor)(a,b);w._textStyle_setDecorationStyle=(a,b)=>(w._textStyle_setDecorationStyle=W.textStyle_setDecorationStyle)(a,b);w._textStyle_setDecorationThickness=(a,b)=>(w._textStyle_setDecorationThickness=W.textStyle_setDecorationThickness)(a,b);w._textStyle_setFontStyle=(a,b,d)=>(w._textStyle_setFontStyle=W.textStyle_setFontStyle)(a,b,d);
w._textStyle_setTextBaseline=(a,b)=>(w._textStyle_setTextBaseline=W.textStyle_setTextBaseline)(a,b);w._textStyle_clearFontFamilies=a=>(w._textStyle_clearFontFamilies=W.textStyle_clearFontFamilies)(a);w._textStyle_addFontFamilies=(a,b,d)=>(w._textStyle_addFontFamilies=W.textStyle_addFontFamilies)(a,b,d);w._textStyle_setFontSize=(a,b)=>(w._textStyle_setFontSize=W.textStyle_setFontSize)(a,b);w._textStyle_setLetterSpacing=(a,b)=>(w._textStyle_setLetterSpacing=W.textStyle_setLetterSpacing)(a,b);
w._textStyle_setWordSpacing=(a,b)=>(w._textStyle_setWordSpacing=W.textStyle_setWordSpacing)(a,b);w._textStyle_setHeight=(a,b)=>(w._textStyle_setHeight=W.textStyle_setHeight)(a,b);w._textStyle_setHalfLeading=(a,b)=>(w._textStyle_setHalfLeading=W.textStyle_setHalfLeading)(a,b);w._textStyle_setLocale=(a,b)=>(w._textStyle_setLocale=W.textStyle_setLocale)(a,b);w._textStyle_setBackground=(a,b)=>(w._textStyle_setBackground=W.textStyle_setBackground)(a,b);
w._textStyle_setForeground=(a,b)=>(w._textStyle_setForeground=W.textStyle_setForeground)(a,b);w._textStyle_addShadow=(a,b,d,e,f)=>(w._textStyle_addShadow=W.textStyle_addShadow)(a,b,d,e,f);w._textStyle_addFontFeature=(a,b,d)=>(w._textStyle_addFontFeature=W.textStyle_addFontFeature)(a,b,d);w._textStyle_setFontVariations=(a,b,d,e)=>(w._textStyle_setFontVariations=W.textStyle_setFontVariations)(a,b,d,e);w._vertices_create=(a,b,d,e,f,h,l)=>(w._vertices_create=W.vertices_create)(a,b,d,e,f,h,l);
w._vertices_dispose=a=>(w._vertices_dispose=W.vertices_dispose)(a);w._animatedImage_create=(a,b,d)=>(w._animatedImage_create=W.animatedImage_create)(a,b,d);w._animatedImage_dispose=a=>(w._animatedImage_dispose=W.animatedImage_dispose)(a);w._animatedImage_getFrameCount=a=>(w._animatedImage_getFrameCount=W.animatedImage_getFrameCount)(a);w._animatedImage_getRepetitionCount=a=>(w._animatedImage_getRepetitionCount=W.animatedImage_getRepetitionCount)(a);
w._animatedImage_getCurrentFrameDurationMilliseconds=a=>(w._animatedImage_getCurrentFrameDurationMilliseconds=W.animatedImage_getCurrentFrameDurationMilliseconds)(a);w._animatedImage_decodeNextFrame=a=>(w._animatedImage_decodeNextFrame=W.animatedImage_decodeNextFrame)(a);w._animatedImage_getCurrentFrame=a=>(w._animatedImage_getCurrentFrame=W.animatedImage_getCurrentFrame)(a);w._skwasm_isHeavy=()=>(w._skwasm_isHeavy=W.skwasm_isHeavy)();
w._paragraphBuilder_create=(a,b)=>(w._paragraphBuilder_create=W.paragraphBuilder_create)(a,b);w._paragraphBuilder_build=a=>(w._paragraphBuilder_build=W.paragraphBuilder_build)(a);w._paragraphBuilder_setGraphemeBreaksUtf16=(a,b)=>(w._paragraphBuilder_setGraphemeBreaksUtf16=W.paragraphBuilder_setGraphemeBreaksUtf16)(a,b);w._paragraphBuilder_setWordBreaksUtf16=(a,b)=>(w._paragraphBuilder_setWordBreaksUtf16=W.paragraphBuilder_setWordBreaksUtf16)(a,b);
w._paragraphBuilder_setLineBreaksUtf16=(a,b)=>(w._paragraphBuilder_setLineBreaksUtf16=W.paragraphBuilder_setLineBreaksUtf16)(a,b);w._dummyAPICalls=()=>(w._dummyAPICalls=W.dummyAPICalls)();w._skwasm_isWimp=()=>(w._skwasm_isWimp=W.skwasm_isWimp)();
var Gb=a=>(Gb=W.malloc)(a),zc=(a,b)=>(zc=W._emscripten_timeout)(a,b),X=(a,b)=>(X=W.setThrew)(a,b),Y=a=>(Y=W._emscripten_stack_restore)(a),ic=a=>(ic=W._emscripten_stack_alloc)(a),Z=()=>(Z=W.emscripten_stack_get_current)(),Aa=(a,b)=>(Aa=W._emscripten_wasm_worker_initialize)(a,b);function Bc(a,b,d){var e=Z();try{return B.get(a)(b,d)}catch(f){Y(e);if(f!==f+0)throw f;X(1,0)}}function Gc(a,b,d){var e=Z();try{B.get(a)(b,d)}catch(f){Y(e);if(f!==f+0)throw f;X(1,0)}}
function Ac(a,b){var d=Z();try{return B.get(a)(b)}catch(e){Y(d);if(e!==e+0)throw e;X(1,0)}}function Hc(a,b,d,e){var f=Z();try{B.get(a)(b,d,e)}catch(h){Y(f);if(h!==h+0)throw h;X(1,0)}}function Cc(a,b,d,e){var f=Z();try{return B.get(a)(b,d,e)}catch(h){Y(f);if(h!==h+0)throw h;X(1,0)}}function Dc(a,b,d,e,f){var h=Z();try{return B.get(a)(b,d,e,f)}catch(l){Y(h);if(l!==l+0)throw l;X(1,0)}}function Ic(a,b,d,e,f,h,l,m){var n=Z();try{B.get(a)(b,d,e,f,h,l,m)}catch(r){Y(n);if(r!==r+0)throw r;X(1,0)}}
function Fc(a,b){var d=Z();try{B.get(a)(b)}catch(e){Y(d);if(e!==e+0)throw e;X(1,0)}}function Ec(a,b,d,e,f,h,l){var m=Z();try{return B.get(a)(b,d,e,f,h,l)}catch(n){Y(m);if(n!==n+0)throw n;X(1,0)}}w.wasmMemory=g;w.wasmExports=W;w.stackAlloc=jc;
w.addFunction=(a,b)=>{if(!V){V=new WeakMap;var d=B.length;if(V)for(var e=0;e<0+d;e++){var f=B.get(e);f&&V.set(f,e)}}if(d=V.get(a)||0)return d;if(hc.length)d=hc.pop();else{try{B.grow(1)}catch(m){if(!(m instanceof RangeError))throw m;throw"Unable to grow wasm table. Set ALLOW_TABLE_GROWTH.";}d=B.length-1}try{B.set(d,a)}catch(m){if(!(m instanceof TypeError))throw m;if("function"==typeof WebAssembly.Function){e=WebAssembly.Function;f={i:"i32",j:"i64",f:"f32",d:"f64",e:"externref",p:"i32"};for(var h={parameters:[],
results:"v"==b[0]?[]:[f[b[0]]]},l=1;l<b.length;++l)h.parameters.push(f[b[l]]);b=new e(h,a)}else{e=[1];f=b.slice(0,1);b=b.slice(1);h={i:127,p:127,j:126,f:125,d:124,e:111};e.push(96);l=b.length;128>l?e.push(l):e.push(l%128|128,l>>7);for(l=0;l<b.length;++l)e.push(h[b[l]]);"v"==f?e.push(0):e.push(1,h[f]);b=[0,97,115,109,1,0,0,0,1];f=e.length;128>f?b.push(f):b.push(f%128|128,f>>7);b.push(...e);b.push(2,7,1,1,101,1,102,0,0,7,5,1,1,102,0,0);b=new WebAssembly.Module(new Uint8Array(b));b=(new WebAssembly.Instance(b,
{e:{f:a}})).exports.f}B.set(d,b)}V.set(a,d);return d};var Kc,Lc;A=function Mc(){Kc||Nc();Kc||(A=Mc)};function Nc(){if(!(0<z))if(ka)ea(w),ya();else{if(!Lc&&(Lc=1,Ea(va),0<z))return;Kc||(Kc=1,w.calledRun=1,ra||(ya(),ea(w),Ea(xa)))}}Nc();moduleRtn=ha;


  return moduleRtn;
}
);
})();
export default wimp;
