

QFileDialog {
    background-color: #222222;
    min-width: 900;
    min-height: 900;
}

QFileDialog QPushButton {
    background-color: red;
    min-width: 80;
    min-height: 40;
}

QFileDialog QLabel {
    color: #FFFFFF;
}

QFileDialog QWidget {
    font-size: 20px;
}

QLabel#OpMode {
    font-size: 26px;
    color: #FFFFFF;
}

QPushButton#OpMode {
    color: #FFFFFF;
    background-color: #345475;
    font-size: 32px;
    border-radius: 5px;
    text-align: left;
}
