QPushButton#ToolSelect {
    color: #FFFFFF;
    background-color: #345475;
    font-size: 26px;
    border-radius: 5px;
}

QPushButton#ToolSelectStandard {
    color: #FFFFFF;
    background-color:rgb(96, 160, 224);
    font-size: 26px;
    border-radius: 5px;
}

QPushButton#ToolSelectHighlight {
    color: #FFFFFF;
    background-color:rgba(96, 224, 102, 1);
    font-size: 26px;
    border-radius: 5px;
}

QPushButton#ToolSelect {
    color: #FFFFFF;
    background-color: #345475;
    font-size: 26px;
    border-radius: 5px;
}

QLabel#ToolSelect {
    color: #FFFFFF;
    font-size: 36px;
}