QWidget#MdiWidget {
    background-color: $main-background;
}

QLabel#MdiTitle {
    color: #FFFFFF;
    background-color: $main-background;
}

QLabel#MdiLabel {
    color: #FFFFFF;
}

QLineEdit#MdiLineEdit {
    color: #FFFFFF;
    background-color: #444444;
    border: 2px solid #888888;
}

QListWidget#MDI {
    color: #FFFFFF;
    background: #2f2f2f;
}

QListWidget#MDI::item {
    background-color: #666666;
}

QListWidget#MDI::item::alternate {
    background-color: #333333;
}