QLabel#Homing {
    color: #FFFFFF;
    font-size: 36px;
}

QLabel#HomingStatusRed {
    color: #ff0000;
    font-size: 36px;
}

QLabel#HomingStatusYellow {
    color: #ffff00;
    font-size: 36px;
}

QLabel#HomingStatusGreen {
    color: #00be66;
    font-size: 36px;
}

QProgressBar#Homing {
    color: #FFFFFF;
    text-align: center;
    font-size: 32px;
    background-color: #444444;
    border: 2px solid white;
    border-radius: 5px;
    margin: 0.5px;
    height: 60px;
}

QProgressBar#Homing::chunk {
    background-color: green;
}

QPushButton#HomingAbortButtonRed {
    color: #000000;
    background-color: #d34739;
    border-radius: 5px;
    padding: 5px;
    min-height: 60px;
    font-size: 48px;
    min-width: 60px;
}