QLabel#StatusMiniLabel {
    color: #FFFFFF;
    background-color: #444444;
}

QLabel#StatusMiniReadout {
    color: #000000;
    background-color: #ADB5BD;
}

QLabel#StatusMiniNumericReadout {
    color: #000000;
    background-color: #ADB5BD;
}

QLabel#StatusMiniNumericReadoutWarning {
    color: #000000;
    background-color: #dd2909;
}