QMenu#PlotMenu {
    background-color: #444444;
}

QPushButton#PlotButton {
    color: #FFFFFF;
    background-color: #345475;
    font-size: 26px;
    border-radius: 5px;
}

QPushButton#PlotButtonSelected {
    color: #FFFFFF;
    background-color: #008966;
    border-radius: 5px;
}

QLabel#PlotButtonSelected {
    color: #FFFFFF;
    background-color: #008966;
    border-radius: 5px;
}

QPushButton#PlotMenuButton {
    color: #FFFFFF;
    background-color: #345475;
    border-radius: 5px;
}

QLabel#PlotMenuButton {
    color: #FFFFFF;
    background-color: #345475;
    border-radius: 5px;
}

QCheckBox#PlotMenuButton {
    margin: 5px 10px;
    color: #FFFFFF;
    background-color: #345475;
    border-radius: 5px;
    font-size: 22px;
}

QCheckBox::indicator::unchecked#PlotMenuButton {
    image: url('res/check_empty.png');
    width: 40px;
    height: 40px;
}

QCheckBox::indicator::checked#PlotMenuButton {
    image: url('res/checked.png');
    width: 40px;
    height: 40px;

}