QLabel#JogLabel {
    color: #000000;
    background-color: #ADB5BD;
}

QLabel#JogLabelSmall {
    color: #000000;
    background-color: #ADB5BD;
}

QLabel#JogReadout {
    color: #000000;
    background-color: #ADB5BD;
    font-size: 25px;
    border-radius: 5px;
}

QPushButton#JogButton {
    color: #FFFFFF;
    background-color: #345475;
    border-radius: 5px;
}

QLabel#JogButton {
    color: #FFFFFF;
    background-color: #345475;
    border-radius: 5px;
}

QPushButton#JogButtonOrigin {
    color: #FFFFFF;
    background-color: #345475;
    border-radius: 5px;
}

QLabel#JogButtonOrigin {
    color: #FFFFFF;
    background-color: #345475;
    border-radius: 5px;
}

QPushButton#JogButtonDisabled {
    color: #FFFFFF;
    background-color: #444444;
    border-radius: 5px;
}

QLabel#JogButtonDisabled {
    color: #FFFFFF;
    background-color: #444444;
    border-radius: 5px;
}

QPushButton#JogButtonSelected {
    color: #FFFFFF;
    background-color: #008966;
    border-radius: 5px;
}

QLabel#JogButtonSelected {
    color: #FFFFFF;
    background-color: #008966;
    border-radius: 5px;
}

QLabel#JogText {
    color: #FFFFFF;
}